/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"

#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringview.sip"
#include <qstringview.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 48 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 1399 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <Qt>
#line 51 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcalendar.sip"
#include <qcalendar.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"


PyDoc_STRVAR(doc_QLocale_language, "language(self) -> QLocale.Language");

extern "C" {static PyObject *meth_QLocale_language(PyObject *, PyObject *);}
static PyObject *meth_QLocale_language(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Language sipRes;

            sipRes = sipCpp->language();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Language);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_language, doc_QLocale_language);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_country, "country(self) -> QLocale.Country");

extern "C" {static PyObject *meth_QLocale_country(PyObject *, PyObject *);}
static PyObject *meth_QLocale_country(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Country sipRes;

            sipRes = sipCpp->country();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Country);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_country, doc_QLocale_country);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_name, "name(self, separator: QLocale.TagSeparator = QLocale.TagSeparator.Underscore) -> str");

extern "C" {static PyObject *meth_QLocale_name(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_name(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = static_cast<int>(QLocale::TagSeparator::Underscore);
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_separator,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_TagSeparator, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name(static_cast< ::QLocale::TagSeparator>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_name, doc_QLocale_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toShort, "toShort(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toShort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toShort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            short sipRes;

            sipRes = sipCpp->toShort(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(hb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toShort, doc_QLocale_toShort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUShort, "toUShort(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toUShort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUShort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::ushort sipRes;

            sipRes = sipCpp->toUShort(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(tb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUShort, doc_QLocale_toUShort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toInt, "toInt(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toInt(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toInt(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->toInt(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ib)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toInt, doc_QLocale_toInt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUInt, "toUInt(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toUInt(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUInt(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::uint sipRes;

            sipRes = sipCpp->toUInt(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ub)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUInt, doc_QLocale_toUInt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLongLong, "toLongLong(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toLongLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLongLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::qlonglong sipRes;

            sipRes = sipCpp->toLongLong(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(nb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLongLong, doc_QLocale_toLongLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toULongLong, "toULongLong(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toULongLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toULongLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::qulonglong sipRes;

            sipRes = sipCpp->toULongLong(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ob)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toULongLong, doc_QLocale_toULongLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toFloat, "toFloat(self, s: str|None) -> (float, bool)");

extern "C" {static PyObject *meth_QLocale_toFloat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toFloat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            float sipRes;

            sipRes = sipCpp->toFloat(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(fb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toFloat, doc_QLocale_toFloat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDouble, "toDouble(self, s: str|None) -> (float, bool)");

extern "C" {static PyObject *meth_QLocale_toDouble(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDouble(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            double sipRes;

            sipRes = sipCpp->toDouble(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(db)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDouble, doc_QLocale_toDouble);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toString, "toString(self, date: QDate|datetime.date, format: QLocale.FormatType, cal: QCalendar) -> str\n"
"toString(self, date: QDate|datetime.date, formatStr: str, cal: QCalendar) -> str\n"
"toString(self, date: QDate|datetime.date, format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, date: QDate|datetime.date, formatStr: str) -> str\n"
"toString(self, time: QTime|datetime.time, format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, time: QTime|datetime.time, formatStr: str) -> str\n"
"toString(self, i: float, format: str = 'g', precision: int = 6) -> str\n"
"toString(self, dateTime: QDateTime|datetime.datetime, format: QLocale.FormatType, cal: QCalendar) -> str\n"
"toString(self, dateTime: QDateTime|datetime.datetime, format: str|None) -> str\n"
"toString(self, dateTime: QDateTime|datetime.datetime, formatStr: str|None, cal: QCalendar) -> str\n"
"toString(self, dateTime: QDateTime|datetime.datetime, format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, i: int) -> str");

extern "C" {static PyObject *meth_QLocale_toString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QDate* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1, *a2));
            sipReleaseType(a0, sipType_QDate, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        ::QDate* a0;
        int a0State = 0;
        ::QStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QStringView, &a1, &a1State, &a1UserState, sipType_QCalendar, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1, *a2));
            sipReleaseType(a0, sipType_QDate, a0State);
            sipReleaseTypeUS(a1, sipType_QStringView, a1State, a1UserState);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        ::QDate* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(a0, sipType_QDate, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        ::QDate* a0;
        int a0State = 0;
        ::QStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QStringView, &a1, &a1State, &a1UserState))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(a0, sipType_QDate, a0State);
            sipReleaseTypeUS(a1, sipType_QStringView, a1State, a1UserState);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        ::QTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QTime, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(a0, sipType_QTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        ::QTime* a0;
        int a0State = 0;
        ::QStringView* a1;
        int a1State = 0;
        void *a1UserState = SIP_NULLPTR;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QTime, &a0, &a0State, sipType_QStringView, &a1, &a1State, &a1UserState))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(a0, sipType_QTime, a0State);
            sipReleaseTypeUS(a1, sipType_QStringView, a1State, a1UserState);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        double a0;
        char a1 = 'g';
        int a2 = 6;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_precision,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BXd|aAi", &sipSelf, sipType_QLocale, &sipCpp, &a0, &a1, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1, *a2));
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QString*sipRes = 0;

#line 811 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
        // QStringView has issues being implemented as a mapped type.
        sipRes = new QString(sipCpp->toString(*a0, QStringView(*a1), *a2));
#line 644 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(const_cast< ::QDateTime *>(a0), sipType_QDateTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BP0", &sipSelf, sipType_QLocale, &sipCpp, &a0))
        {
            ::QString*sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 1107 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
        // Convert a Python int avoiding overflow as much as possible.
        
        static PyObject *zero = 0;
        if (!zero)
            zero = PyLong_FromLong(0);
        
        int rc = PyObject_RichCompareBool(a0, zero, Py_LT);
        
        PyErr_Clear();
        
        if (rc < 0)
        {
            sipError = sipBadCallableArg(0, a0);
        }
        else if (rc)
        {
            long long value = PyLong_AsLongLong(a0);
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toString(value));
            }
        }
        else
        {
            unsigned long long value = PyLong_AsUnsignedLongLongMask(a0);
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toString(value));
            }
        }
#line 724 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toString, doc_QLocale_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_languageToString, "languageToString(language: QLocale.Language) -> str");

extern "C" {static PyObject *meth_QLocale_languageToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_languageToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Language, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::languageToString(static_cast< ::QLocale::Language>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_languageToString, doc_QLocale_languageToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_countryToString, "countryToString(country: QLocale.Country) -> str");

extern "C" {static PyObject *meth_QLocale_countryToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_countryToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Country, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::countryToString(static_cast< ::QLocale::Country>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_countryToString, doc_QLocale_countryToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_setDefault, "setDefault(locale: QLocale)");

extern "C" {static PyObject *meth_QLocale_setDefault(PyObject *, PyObject *);}
static PyObject *meth_QLocale_setDefault(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ9", &sipSelf, sipType_QLocale, &a0))
        {
            ::QLocale::setDefault(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_setDefault, doc_QLocale_setDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_c, "c() -> QLocale");

extern "C" {static PyObject *meth_QLocale_c(PyObject *, PyObject *);}
static PyObject *meth_QLocale_c(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(::QLocale::c());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_c, doc_QLocale_c);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_system, "system() -> QLocale");

extern "C" {static PyObject *meth_QLocale_system(PyObject *, PyObject *);}
static PyObject *meth_QLocale_system(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(::QLocale::system());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_system, doc_QLocale_system);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dateFormat, "dateFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dateFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dateFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dateFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dateFormat, doc_QLocale_dateFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_timeFormat, "timeFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_timeFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_timeFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->timeFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_timeFormat, doc_QLocale_timeFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dateTimeFormat, "dateTimeFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dateTimeFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dateTimeFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dateTimeFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dateTimeFormat, doc_QLocale_dateTimeFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDate, "toDate(self, string: str|None, format: str|None, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDate\n"
"toDate(self, string: str|None, format: str|None, cal: QCalendar, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDate\n"
"toDate(self, string: str|None, format: QLocale.FormatType, cal: QCalendar, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDate\n"
"toDate(self, string: str|None, a1: QLocale.FormatType = QLocale.LongFormat, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDate");

extern "C" {static PyObject *meth_QLocale_toDate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        int a2 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, &a2))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, *a1, a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        int a3 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1J9|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2, &a3))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, *a1, *a2, a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        int a3 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1EJ9|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2, &a3))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, a1, *a2, a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        int a2 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|Ei", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, &a2))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, a1, a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDate, doc_QLocale_toDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toTime, "toTime(self, string: str|None, format: QLocale.FormatType = QLocale.LongFormat) -> QTime\n"
"toTime(self, string: str|None, format: str|None) -> QTime");

extern "C" {static PyObject *meth_QLocale_toTime(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toTime(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toTime, doc_QLocale_toTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDateTime, "toDateTime(self, string: str|None, format: str|None, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDateTime\n"
"toDateTime(self, string: str|None, format: str|None, cal: QCalendar, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDateTime\n"
"toDateTime(self, string: str|None, format: QLocale.FormatType, cal: QCalendar, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDateTime\n"
"toDateTime(self, string: str|None, format: QLocale.FormatType = QLocale.LongFormat, baseYear: int = QLocale.DefaultTwoDigitBaseYear) -> QDateTime");

extern "C" {static PyObject *meth_QLocale_toDateTime(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDateTime(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        int a2 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, &a2))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, *a1, a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        int a3 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1J9|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2, &a3))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, *a1, *a2, a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        int a3 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1EJ9|i", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2, &a3))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, a1, *a2, a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        int a2 = QLocale::DefaultTwoDigitBaseYear;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_baseYear,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|Ei", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, &a2))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, a1, a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDateTime, doc_QLocale_toDateTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_decimalPoint, "decimalPoint(self) -> str");

extern "C" {static PyObject *meth_QLocale_decimalPoint(PyObject *, PyObject *);}
static PyObject *meth_QLocale_decimalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->decimalPoint());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_decimalPoint, doc_QLocale_decimalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_groupSeparator, "groupSeparator(self) -> str");

extern "C" {static PyObject *meth_QLocale_groupSeparator(PyObject *, PyObject *);}
static PyObject *meth_QLocale_groupSeparator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->groupSeparator());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_groupSeparator, doc_QLocale_groupSeparator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_percent, "percent(self) -> str");

extern "C" {static PyObject *meth_QLocale_percent(PyObject *, PyObject *);}
static PyObject *meth_QLocale_percent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->percent());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_percent, doc_QLocale_percent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_zeroDigit, "zeroDigit(self) -> str");

extern "C" {static PyObject *meth_QLocale_zeroDigit(PyObject *, PyObject *);}
static PyObject *meth_QLocale_zeroDigit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->zeroDigit());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_zeroDigit, doc_QLocale_zeroDigit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_negativeSign, "negativeSign(self) -> str");

extern "C" {static PyObject *meth_QLocale_negativeSign(PyObject *, PyObject *);}
static PyObject *meth_QLocale_negativeSign(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->negativeSign());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_negativeSign, doc_QLocale_negativeSign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_exponential, "exponential(self) -> str");

extern "C" {static PyObject *meth_QLocale_exponential(PyObject *, PyObject *);}
static PyObject *meth_QLocale_exponential(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->exponential());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_exponential, doc_QLocale_exponential);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_monthName, "monthName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_monthName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_monthName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->monthName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_monthName, doc_QLocale_monthName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dayName, "dayName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dayName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dayName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dayName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dayName, doc_QLocale_dayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_setNumberOptions, "setNumberOptions(self, options: QLocale.NumberOption)");

extern "C" {static PyObject *meth_QLocale_setNumberOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocale_setNumberOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::NumberOptions* a0;
        int a0State = 0;
        ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QFlags_0100QLocale_NumberOption, &a0, &a0State))
        {
            sipCpp->setNumberOptions(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QLocale_NumberOption, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_setNumberOptions, doc_QLocale_setNumberOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_numberOptions, "numberOptions(self) -> QLocale.NumberOption");

extern "C" {static PyObject *meth_QLocale_numberOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocale_numberOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::NumberOptions*sipRes;

            sipRes = new ::QLocale::NumberOptions(sipCpp->numberOptions());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QLocale_NumberOption, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_numberOptions, doc_QLocale_numberOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_measurementSystem, "measurementSystem(self) -> QLocale.MeasurementSystem");

extern "C" {static PyObject *meth_QLocale_measurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QLocale_measurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::MeasurementSystem sipRes;

            sipRes = sipCpp->measurementSystem();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_MeasurementSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_measurementSystem, doc_QLocale_measurementSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_positiveSign, "positiveSign(self) -> str");

extern "C" {static PyObject *meth_QLocale_positiveSign(PyObject *, PyObject *);}
static PyObject *meth_QLocale_positiveSign(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->positiveSign());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_positiveSign, doc_QLocale_positiveSign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_standaloneMonthName, "standaloneMonthName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_standaloneMonthName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_standaloneMonthName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->standaloneMonthName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_standaloneMonthName, doc_QLocale_standaloneMonthName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_standaloneDayName, "standaloneDayName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_standaloneDayName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_standaloneDayName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->standaloneDayName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_standaloneDayName, doc_QLocale_standaloneDayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_amText, "amText(self) -> str");

extern "C" {static PyObject *meth_QLocale_amText(PyObject *, PyObject *);}
static PyObject *meth_QLocale_amText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->amText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_amText, doc_QLocale_amText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_pmText, "pmText(self) -> str");

extern "C" {static PyObject *meth_QLocale_pmText(PyObject *, PyObject *);}
static PyObject *meth_QLocale_pmText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pmText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_pmText, doc_QLocale_pmText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_textDirection, "textDirection(self) -> Qt.LayoutDirection");

extern "C" {static PyObject *meth_QLocale_textDirection(PyObject *, PyObject *);}
static PyObject *meth_QLocale_textDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::Qt::LayoutDirection sipRes;

            sipRes = sipCpp->textDirection();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_LayoutDirection);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_textDirection, doc_QLocale_textDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_script, "script(self) -> QLocale.Script");

extern "C" {static PyObject *meth_QLocale_script(PyObject *, PyObject *);}
static PyObject *meth_QLocale_script(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Script sipRes;

            sipRes = sipCpp->script();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Script);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_script, doc_QLocale_script);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_bcp47Name, "bcp47Name(self, separator: QLocale.TagSeparator = QLocale.TagSeparator.Dash) -> str");

extern "C" {static PyObject *meth_QLocale_bcp47Name(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_bcp47Name(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = static_cast<int>(QLocale::TagSeparator::Dash);
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_separator,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_TagSeparator, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->bcp47Name(static_cast< ::QLocale::TagSeparator>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_bcp47Name, doc_QLocale_bcp47Name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_nativeLanguageName, "nativeLanguageName(self) -> str");

extern "C" {static PyObject *meth_QLocale_nativeLanguageName(PyObject *, PyObject *);}
static PyObject *meth_QLocale_nativeLanguageName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeLanguageName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_nativeLanguageName, doc_QLocale_nativeLanguageName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_nativeCountryName, "nativeCountryName(self) -> str");

extern "C" {static PyObject *meth_QLocale_nativeCountryName(PyObject *, PyObject *);}
static PyObject *meth_QLocale_nativeCountryName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeCountryName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_nativeCountryName, doc_QLocale_nativeCountryName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_firstDayOfWeek, "firstDayOfWeek(self) -> Qt.DayOfWeek");

extern "C" {static PyObject *meth_QLocale_firstDayOfWeek(PyObject *, PyObject *);}
static PyObject *meth_QLocale_firstDayOfWeek(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::Qt::DayOfWeek sipRes;

            sipRes = sipCpp->firstDayOfWeek();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_DayOfWeek);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_firstDayOfWeek, doc_QLocale_firstDayOfWeek);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_weekdays, "weekdays(self) -> list[Qt.DayOfWeek]");

extern "C" {static PyObject *meth_QLocale_weekdays(PyObject *, PyObject *);}
static PyObject *meth_QLocale_weekdays(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QList< ::Qt::DayOfWeek>*sipRes;

            sipRes = new ::QList< ::Qt::DayOfWeek>(sipCpp->weekdays());

            return sipConvertFromNewType(sipRes, sipType_QList_0100Qt_DayOfWeek, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_weekdays, doc_QLocale_weekdays);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUpper, "toUpper(self, str: str|None) -> str");

extern "C" {static PyObject *meth_QLocale_toUpper(PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUpper(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toUpper(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUpper, doc_QLocale_toUpper);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLower, "toLower(self, str: str|None) -> str");

extern "C" {static PyObject *meth_QLocale_toLower(PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLower(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toLower(*a0));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLower, doc_QLocale_toLower);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_currencySymbol, "currencySymbol(self, format: QLocale.CurrencySymbolFormat = QLocale.CurrencySymbol) -> str");

extern "C" {static PyObject *meth_QLocale_currencySymbol(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_currencySymbol(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::CurrencySymbolFormat a0 = QLocale::CurrencySymbol;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_CurrencySymbolFormat, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->currencySymbol(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_currencySymbol, doc_QLocale_currencySymbol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toCurrencyString, "toCurrencyString(self, a0: float, symbol: str|None = '', precision: int = -1) -> str\n"
"toCurrencyString(self, value: int, symbol: str|None = '') -> str");

extern "C" {static PyObject *meth_QLocale_toCurrencyString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toCurrencyString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        int a2 = -1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_symbol,
            sipName_precision,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bd|J1i", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QString, &a1, &a1State, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toCurrencyString(a0, *a1, a2));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_symbol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BP0|J1", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 1151 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
        // Convert a Python int avoiding overflow as much as possible.
        
        static PyObject *zero = 0;
        if (!zero)
            zero = PyLong_FromLong(0);
        
        int rc = PyObject_RichCompareBool(a0, zero, Py_LT);
        
        PyErr_Clear();
        
        if (rc < 0)
        {
            sipError = sipBadCallableArg(0, a0);
        }
        else if (rc)
        {
            long long value = PyLong_AsLongLong(a0);
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toCurrencyString(value, *a1));
            }
        }
        else
        {
            unsigned long long value = PyLong_AsUnsignedLongLongMask(a0);
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toCurrencyString(value, *a1));
            }
        }
#line 2070 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toCurrencyString, doc_QLocale_toCurrencyString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_uiLanguages, "uiLanguages(self, separator: QLocale.TagSeparator = QLocale.TagSeparator.Dash) -> list[str]");

extern "C" {static PyObject *meth_QLocale_uiLanguages(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_uiLanguages(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0 = static_cast<int>(QLocale::TagSeparator::Dash);
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_separator,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_TagSeparator, &a0))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->uiLanguages(static_cast< ::QLocale::TagSeparator>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_uiLanguages, doc_QLocale_uiLanguages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_scriptToString, "scriptToString(script: QLocale.Script) -> str");

extern "C" {static PyObject *meth_QLocale_scriptToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_scriptToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Script, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::scriptToString(static_cast< ::QLocale::Script>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_scriptToString, doc_QLocale_scriptToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_matchingLocales, "matchingLocales(language: QLocale.Language, script: QLocale.Script, territory: QLocale.Country) -> list[QLocale]");

extern "C" {static PyObject *meth_QLocale_matchingLocales(PyObject *, PyObject *);}
static PyObject *meth_QLocale_matchingLocales(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "CEEE", &sipSelf, sipType_QLocale_Language, &a0, sipType_QLocale_Script, &a1, sipType_QLocale_Country, &a2))
        {
            QList< ::QLocale>*sipRes;

            sipRes = new QList< ::QLocale>(::QLocale::matchingLocales(static_cast< ::QLocale::Language>(a0), static_cast< ::QLocale::Script>(a1), static_cast< ::QLocale::Country>(a2)));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_matchingLocales, doc_QLocale_matchingLocales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_quoteString, "quoteString(self, str: str, style: QLocale.QuotationStyle = QLocale.StandardQuotation) -> str");

extern "C" {static PyObject *meth_QLocale_quoteString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_quoteString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QLocale::QuotationStyle a1 = QLocale::StandardQuotation;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_style,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QStringView, &a0, &a0State, &a0UserState, sipType_QLocale_QuotationStyle, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->quoteString(*a0, a1));
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_quoteString, doc_QLocale_quoteString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_createSeparatedList, "createSeparatedList(self, list: Iterable[str|None]) -> str");

extern "C" {static PyObject *meth_QLocale_createSeparatedList(PyObject *, PyObject *);}
static PyObject *meth_QLocale_createSeparatedList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->createSeparatedList(*a0));
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_createSeparatedList, doc_QLocale_createSeparatedList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_swap, "swap(self, other: QLocale)");

extern "C" {static PyObject *meth_QLocale_swap(PyObject *, PyObject *);}
static PyObject *meth_QLocale_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale* a0;
        ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_swap, doc_QLocale_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_formattedDataSize, "formattedDataSize(self, bytes: int, precision: int = 2, format: QLocale.DataSizeFormat = QLocale.DataSizeIecFormat) -> str");

extern "C" {static PyObject *meth_QLocale_formattedDataSize(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_formattedDataSize(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        int a1 = 2;
        ::QLocale::DataSizeFormats a2def = QLocale::DataSizeIecFormat;
        ::QLocale::DataSizeFormats* a2 = &a2def;
        int a2State = 0;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_precision,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bn|iJ1", &sipSelf, sipType_QLocale, &sipCpp, &a0, &a1, sipType_QFlags_0100QLocale_DataSizeFormat, &a2, &a2State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->formattedDataSize(a0, a1, *a2));
            sipReleaseType(a2, sipType_QFlags_0100QLocale_DataSizeFormat, a2State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_formattedDataSize, doc_QLocale_formattedDataSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLong, "toLong(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            long sipRes;

            sipRes = sipCpp->toLong(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(lb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLong, doc_QLocale_toLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toULong, "toULong(self, s: str|None) -> (int, bool)");

extern "C" {static PyObject *meth_QLocale_toULong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toULong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::ulong sipRes;

            sipRes = sipCpp->toULong(*a0, &a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(mb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toULong, doc_QLocale_toULong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_collation, "collation(self) -> QLocale");

extern "C" {static PyObject *meth_QLocale_collation(PyObject *, PyObject *);}
static PyObject *meth_QLocale_collation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->collation());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_collation, doc_QLocale_collation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_languageToCode, "languageToCode(language: QLocale.Language, codeTypes: QLocale.LanguageCodeType = QLocale.AnyLanguageCode) -> str");

extern "C" {static PyObject *meth_QLocale_languageToCode(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_languageToCode(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::LanguageCodeTypes a1def = QLocale::AnyLanguageCode;
        ::QLocale::LanguageCodeTypes* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_codeTypes,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CE|J1", &sipSelf, sipType_QLocale_Language, &a0, sipType_QFlags_0100QLocale_LanguageCodeType, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::languageToCode(static_cast< ::QLocale::Language>(a0), *a1));
            sipReleaseType(a1, sipType_QFlags_0100QLocale_LanguageCodeType, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_languageToCode, doc_QLocale_languageToCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_codeToLanguage, "codeToLanguage(languageCode: str, codeTypes: QLocale.LanguageCodeType = QLocale.AnyLanguageCode) -> QLocale.Language");

extern "C" {static PyObject *meth_QLocale_codeToLanguage(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_codeToLanguage(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;
        ::QLocale::LanguageCodeTypes a1def = QLocale::AnyLanguageCode;
        ::QLocale::LanguageCodeTypes* a1 = &a1def;
        int a1State = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_codeTypes,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "CJ1|J1", &sipSelf, sipType_QStringView, &a0, &a0State, &a0UserState, sipType_QFlags_0100QLocale_LanguageCodeType, &a1, &a1State))
        {
            ::QLocale::Language sipRes;

            sipRes = ::QLocale::codeToLanguage(*a0, *a1);
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);
            sipReleaseType(a1, sipType_QFlags_0100QLocale_LanguageCodeType, a1State);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Language);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_codeToLanguage, doc_QLocale_codeToLanguage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_countryToCode, "countryToCode(country: QLocale.Country) -> str");

extern "C" {static PyObject *meth_QLocale_countryToCode(PyObject *, PyObject *);}
static PyObject *meth_QLocale_countryToCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Country, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::countryToCode(static_cast< ::QLocale::Country>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_countryToCode, doc_QLocale_countryToCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_codeToCountry, "codeToCountry(countryCode: str) -> QLocale.Country");

extern "C" {static PyObject *meth_QLocale_codeToCountry(PyObject *, PyObject *);}
static PyObject *meth_QLocale_codeToCountry(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QStringView, &a0, &a0State, &a0UserState))
        {
            ::QLocale::Country sipRes;

            sipRes = ::QLocale::codeToCountry(*a0);
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Country);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_codeToCountry, doc_QLocale_codeToCountry);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_scriptToCode, "scriptToCode(script: QLocale.Script) -> str");

extern "C" {static PyObject *meth_QLocale_scriptToCode(PyObject *, PyObject *);}
static PyObject *meth_QLocale_scriptToCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Script, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::scriptToCode(static_cast< ::QLocale::Script>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_scriptToCode, doc_QLocale_scriptToCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_codeToScript, "codeToScript(scriptCode: str) -> QLocale.Script");

extern "C" {static PyObject *meth_QLocale_codeToScript(PyObject *, PyObject *);}
static PyObject *meth_QLocale_codeToScript(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QStringView, &a0, &a0State, &a0UserState))
        {
            ::QLocale::Script sipRes;

            sipRes = ::QLocale::codeToScript(*a0);
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Script);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_codeToScript, doc_QLocale_codeToScript);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_territory, "territory(self) -> QLocale.Country");

extern "C" {static PyObject *meth_QLocale_territory(PyObject *, PyObject *);}
static PyObject *meth_QLocale_territory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Territory sipRes;

            sipRes = sipCpp->territory();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Country);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_territory, doc_QLocale_territory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_nativeTerritoryName, "nativeTerritoryName(self) -> str");

extern "C" {static PyObject *meth_QLocale_nativeTerritoryName(PyObject *, PyObject *);}
static PyObject *meth_QLocale_nativeTerritoryName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeTerritoryName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_nativeTerritoryName, doc_QLocale_nativeTerritoryName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_territoryToCode, "territoryToCode(territory: QLocale.Country) -> str");

extern "C" {static PyObject *meth_QLocale_territoryToCode(PyObject *, PyObject *);}
static PyObject *meth_QLocale_territoryToCode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Country, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::territoryToCode(static_cast< ::QLocale::Country>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_territoryToCode, doc_QLocale_territoryToCode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_codeToTerritory, "codeToTerritory(territoryCode: str) -> QLocale.Country");

extern "C" {static PyObject *meth_QLocale_codeToTerritory(PyObject *, PyObject *);}
static PyObject *meth_QLocale_codeToTerritory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QStringView* a0;
        int a0State = 0;
        void *a0UserState = SIP_NULLPTR;

        if (sipParseArgs(&sipParseErr, sipArgs, "CJ1", &sipSelf, sipType_QStringView, &a0, &a0State, &a0UserState))
        {
            ::QLocale::Territory sipRes;

            sipRes = ::QLocale::codeToTerritory(*a0);
            sipReleaseTypeUS(a0, sipType_QStringView, a0State, a0UserState);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Country);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_codeToTerritory, doc_QLocale_codeToTerritory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_territoryToString, "territoryToString(territory: QLocale.Country) -> str");

extern "C" {static PyObject *meth_QLocale_territoryToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_territoryToString(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "CE", &sipSelf, sipType_QLocale_Country, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::territoryToString(static_cast< ::QLocale::Country>(a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_territoryToString, doc_QLocale_territoryToString);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QLocale___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLocale___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLocale *sipCpp = reinterpret_cast< ::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1E", sipType_QLocale_Language, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), static_cast< ::QLocale::Language>(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLocale, &a0))
        {
            bool sipRes;

            sipRes = operator==((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QLocale, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLocale___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLocale___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLocale *sipCpp = reinterpret_cast< ::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1E", sipType_QLocale_Language, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), static_cast< ::QLocale::Language>(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLocale, &a0))
        {
            bool sipRes;

            sipRes = operator!=((*sipCpp), *a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QLocale, sipSelf, sipArg);
}


extern "C" {static Py_hash_t slot_QLocale___hash__(PyObject *);}
static Py_hash_t slot_QLocale___hash__(PyObject *sipSelf)
{
    ::QLocale *sipCpp = reinterpret_cast< ::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return 0;


    {
        {
            Py_hash_t sipRes = 0;

#line 1096 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
        sipRes = qHash(*sipCpp);
#line 2814 "/build/pyqt6/src/pyqt6-6.11.0/build/QtCore/sipQtCoreQLocale.cpp"

            return sipRes;
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QLocale(void *, int);}
static void release_QLocale(void *sipCppV, int)
{
    delete reinterpret_cast< ::QLocale *>(sipCppV);
}


extern "C" {static void *array_QLocale(Py_ssize_t);}
static void *array_QLocale(Py_ssize_t sipNrElem)
{
    return new ::QLocale[sipNrElem];
}


extern "C" {static void array_delete_QLocale(void *);}
static void array_delete_QLocale(void *sipCpp)
{
    delete[] reinterpret_cast< ::QLocale *>(sipCpp);
}


extern "C" {static void assign_QLocale(void *, Py_ssize_t, void *);}
static void assign_QLocale(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QLocale *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QLocale *>(sipSrc);
}


extern "C" {static void *copy_QLocale(const void *, Py_ssize_t);}
static void *copy_QLocale(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLocale(reinterpret_cast<const ::QLocale *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLocale(sipSimpleWrapper *);}
static void dealloc_QLocale(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLocale(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLocale(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLocale(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLocale *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLocale();

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QLocale(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        int a0;
        int a1 = static_cast<int>(QLocale::AnyCountry);

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_country,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|E", sipType_QLocale_Language, &a0, sipType_QLocale_Country, &a1))
        {
            sipCpp = new ::QLocale(static_cast< ::QLocale::Language>(a0), static_cast< ::QLocale::Country>(a1));

            return sipCpp;
        }
    }

    {
        int a0;
        int a1;
        int a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "EEE", sipType_QLocale_Language, &a0, sipType_QLocale_Script, &a1, sipType_QLocale_Country, &a2))
        {
            sipCpp = new ::QLocale(static_cast< ::QLocale::Language>(a0), static_cast< ::QLocale::Script>(a1), static_cast< ::QLocale::Country>(a2));

            return sipCpp;
        }
    }

    {
        const ::QLocale* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLocale, &a0))
        {
            sipCpp = new ::QLocale(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLocale[] = {
    {(void *)slot_QLocale___eq__, eq_slot},
    {(void *)slot_QLocale___ne__, ne_slot},
    {(void *)slot_QLocale___hash__, hash_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLocale[] = {
    {sipName_amText, meth_QLocale_amText, METH_VARARGS, doc_QLocale_amText},
    {sipName_bcp47Name, SIP_MLMETH_CAST(meth_QLocale_bcp47Name), METH_VARARGS|METH_KEYWORDS, doc_QLocale_bcp47Name},
    {sipName_c, meth_QLocale_c, METH_VARARGS, doc_QLocale_c},
    {sipName_codeToCountry, meth_QLocale_codeToCountry, METH_VARARGS, doc_QLocale_codeToCountry},
    {sipName_codeToLanguage, SIP_MLMETH_CAST(meth_QLocale_codeToLanguage), METH_VARARGS|METH_KEYWORDS, doc_QLocale_codeToLanguage},
    {sipName_codeToScript, meth_QLocale_codeToScript, METH_VARARGS, doc_QLocale_codeToScript},
    {sipName_codeToTerritory, meth_QLocale_codeToTerritory, METH_VARARGS, doc_QLocale_codeToTerritory},
    {sipName_collation, meth_QLocale_collation, METH_VARARGS, doc_QLocale_collation},
    {sipName_country, meth_QLocale_country, METH_VARARGS, doc_QLocale_country},
    {sipName_countryToCode, meth_QLocale_countryToCode, METH_VARARGS, doc_QLocale_countryToCode},
    {sipName_countryToString, meth_QLocale_countryToString, METH_VARARGS, doc_QLocale_countryToString},
    {sipName_createSeparatedList, meth_QLocale_createSeparatedList, METH_VARARGS, doc_QLocale_createSeparatedList},
    {sipName_currencySymbol, SIP_MLMETH_CAST(meth_QLocale_currencySymbol), METH_VARARGS|METH_KEYWORDS, doc_QLocale_currencySymbol},
    {sipName_dateFormat, SIP_MLMETH_CAST(meth_QLocale_dateFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dateFormat},
    {sipName_dateTimeFormat, SIP_MLMETH_CAST(meth_QLocale_dateTimeFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dateTimeFormat},
    {sipName_dayName, SIP_MLMETH_CAST(meth_QLocale_dayName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dayName},
    {sipName_decimalPoint, meth_QLocale_decimalPoint, METH_VARARGS, doc_QLocale_decimalPoint},
    {sipName_exponential, meth_QLocale_exponential, METH_VARARGS, doc_QLocale_exponential},
    {sipName_firstDayOfWeek, meth_QLocale_firstDayOfWeek, METH_VARARGS, doc_QLocale_firstDayOfWeek},
    {sipName_formattedDataSize, SIP_MLMETH_CAST(meth_QLocale_formattedDataSize), METH_VARARGS|METH_KEYWORDS, doc_QLocale_formattedDataSize},
    {sipName_groupSeparator, meth_QLocale_groupSeparator, METH_VARARGS, doc_QLocale_groupSeparator},
    {sipName_language, meth_QLocale_language, METH_VARARGS, doc_QLocale_language},
    {sipName_languageToCode, SIP_MLMETH_CAST(meth_QLocale_languageToCode), METH_VARARGS|METH_KEYWORDS, doc_QLocale_languageToCode},
    {sipName_languageToString, meth_QLocale_languageToString, METH_VARARGS, doc_QLocale_languageToString},
    {sipName_matchingLocales, meth_QLocale_matchingLocales, METH_VARARGS, doc_QLocale_matchingLocales},
    {sipName_measurementSystem, meth_QLocale_measurementSystem, METH_VARARGS, doc_QLocale_measurementSystem},
    {sipName_monthName, SIP_MLMETH_CAST(meth_QLocale_monthName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_monthName},
    {sipName_name, SIP_MLMETH_CAST(meth_QLocale_name), METH_VARARGS|METH_KEYWORDS, doc_QLocale_name},
    {sipName_nativeCountryName, meth_QLocale_nativeCountryName, METH_VARARGS, doc_QLocale_nativeCountryName},
    {sipName_nativeLanguageName, meth_QLocale_nativeLanguageName, METH_VARARGS, doc_QLocale_nativeLanguageName},
    {sipName_nativeTerritoryName, meth_QLocale_nativeTerritoryName, METH_VARARGS, doc_QLocale_nativeTerritoryName},
    {sipName_negativeSign, meth_QLocale_negativeSign, METH_VARARGS, doc_QLocale_negativeSign},
    {sipName_numberOptions, meth_QLocale_numberOptions, METH_VARARGS, doc_QLocale_numberOptions},
    {sipName_percent, meth_QLocale_percent, METH_VARARGS, doc_QLocale_percent},
    {sipName_pmText, meth_QLocale_pmText, METH_VARARGS, doc_QLocale_pmText},
    {sipName_positiveSign, meth_QLocale_positiveSign, METH_VARARGS, doc_QLocale_positiveSign},
    {sipName_quoteString, SIP_MLMETH_CAST(meth_QLocale_quoteString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_quoteString},
    {sipName_script, meth_QLocale_script, METH_VARARGS, doc_QLocale_script},
    {sipName_scriptToCode, meth_QLocale_scriptToCode, METH_VARARGS, doc_QLocale_scriptToCode},
    {sipName_scriptToString, meth_QLocale_scriptToString, METH_VARARGS, doc_QLocale_scriptToString},
    {sipName_setDefault, meth_QLocale_setDefault, METH_VARARGS, doc_QLocale_setDefault},
    {sipName_setNumberOptions, meth_QLocale_setNumberOptions, METH_VARARGS, doc_QLocale_setNumberOptions},
    {sipName_standaloneDayName, SIP_MLMETH_CAST(meth_QLocale_standaloneDayName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_standaloneDayName},
    {sipName_standaloneMonthName, SIP_MLMETH_CAST(meth_QLocale_standaloneMonthName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_standaloneMonthName},
    {sipName_swap, meth_QLocale_swap, METH_VARARGS, doc_QLocale_swap},
    {sipName_system, meth_QLocale_system, METH_VARARGS, doc_QLocale_system},
    {sipName_territory, meth_QLocale_territory, METH_VARARGS, doc_QLocale_territory},
    {sipName_territoryToCode, meth_QLocale_territoryToCode, METH_VARARGS, doc_QLocale_territoryToCode},
    {sipName_territoryToString, meth_QLocale_territoryToString, METH_VARARGS, doc_QLocale_territoryToString},
    {sipName_textDirection, meth_QLocale_textDirection, METH_VARARGS, doc_QLocale_textDirection},
    {sipName_timeFormat, SIP_MLMETH_CAST(meth_QLocale_timeFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_timeFormat},
    {sipName_toCurrencyString, SIP_MLMETH_CAST(meth_QLocale_toCurrencyString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toCurrencyString},
    {sipName_toDate, SIP_MLMETH_CAST(meth_QLocale_toDate), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDate},
    {sipName_toDateTime, SIP_MLMETH_CAST(meth_QLocale_toDateTime), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDateTime},
    {sipName_toDouble, SIP_MLMETH_CAST(meth_QLocale_toDouble), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDouble},
    {sipName_toFloat, SIP_MLMETH_CAST(meth_QLocale_toFloat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toFloat},
    {sipName_toInt, SIP_MLMETH_CAST(meth_QLocale_toInt), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toInt},
    {sipName_toLong, SIP_MLMETH_CAST(meth_QLocale_toLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toLong},
    {sipName_toLongLong, SIP_MLMETH_CAST(meth_QLocale_toLongLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toLongLong},
    {sipName_toLower, meth_QLocale_toLower, METH_VARARGS, doc_QLocale_toLower},
    {sipName_toShort, SIP_MLMETH_CAST(meth_QLocale_toShort), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toShort},
    {sipName_toString, SIP_MLMETH_CAST(meth_QLocale_toString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toString},
    {sipName_toTime, SIP_MLMETH_CAST(meth_QLocale_toTime), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toTime},
    {sipName_toUInt, SIP_MLMETH_CAST(meth_QLocale_toUInt), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toUInt},
    {sipName_toULong, SIP_MLMETH_CAST(meth_QLocale_toULong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toULong},
    {sipName_toULongLong, SIP_MLMETH_CAST(meth_QLocale_toULongLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toULongLong},
    {sipName_toUShort, SIP_MLMETH_CAST(meth_QLocale_toUShort), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toUShort},
    {sipName_toUpper, meth_QLocale_toUpper, METH_VARARGS, doc_QLocale_toUpper},
    {sipName_uiLanguages, SIP_MLMETH_CAST(meth_QLocale_uiLanguages), METH_VARARGS|METH_KEYWORDS, doc_QLocale_uiLanguages},
    {sipName_weekdays, meth_QLocale_weekdays, METH_VARARGS, doc_QLocale_weekdays},
    {sipName_zeroDigit, meth_QLocale_zeroDigit, METH_VARARGS, doc_QLocale_zeroDigit}
};


extern "C" {static PyObject *varget_QLocale_DefaultTwoDigitBaseYear(void *, PyObject *, PyObject *);}
static PyObject *varget_QLocale_DefaultTwoDigitBaseYear(void *, PyObject *, PyObject *)
{
    int sipVal;

    sipVal = ::QLocale::DefaultTwoDigitBaseYear;

    return PyLong_FromLong(sipVal);
}

sipVariableDef variables_QLocale[] = {
    {ClassVariable, sipName_DefaultTwoDigitBaseYear, (PyMethodDef *)varget_QLocale_DefaultTwoDigitBaseYear, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QLocale[] = {
    {sipName_AnyCountry, static_cast<int>(::QLocale::AnyCountry)},
    {sipName_AnyTerritory, static_cast<int>(::QLocale::AnyTerritory)},
    {sipName_Afghanistan, static_cast<int>(::QLocale::Afghanistan)},
    {sipName_Albania, static_cast<int>(::QLocale::Albania)},
    {sipName_Algeria, static_cast<int>(::QLocale::Algeria)},
    {sipName_AmericanSamoa, static_cast<int>(::QLocale::AmericanSamoa)},
    {sipName_Andorra, static_cast<int>(::QLocale::Andorra)},
    {sipName_Angola, static_cast<int>(::QLocale::Angola)},
    {sipName_Anguilla, static_cast<int>(::QLocale::Anguilla)},
    {sipName_Antarctica, static_cast<int>(::QLocale::Antarctica)},
    {sipName_AntiguaAndBarbuda, static_cast<int>(::QLocale::AntiguaAndBarbuda)},
    {sipName_Argentina, static_cast<int>(::QLocale::Argentina)},
    {sipName_Armenia, static_cast<int>(::QLocale::Armenia)},
    {sipName_Aruba, static_cast<int>(::QLocale::Aruba)},
    {sipName_Australia, static_cast<int>(::QLocale::Australia)},
    {sipName_Austria, static_cast<int>(::QLocale::Austria)},
    {sipName_Azerbaijan, static_cast<int>(::QLocale::Azerbaijan)},
    {sipName_Bahamas, static_cast<int>(::QLocale::Bahamas)},
    {sipName_Bahrain, static_cast<int>(::QLocale::Bahrain)},
    {sipName_Bangladesh, static_cast<int>(::QLocale::Bangladesh)},
    {sipName_Barbados, static_cast<int>(::QLocale::Barbados)},
    {sipName_Belarus, static_cast<int>(::QLocale::Belarus)},
    {sipName_Belgium, static_cast<int>(::QLocale::Belgium)},
    {sipName_Belize, static_cast<int>(::QLocale::Belize)},
    {sipName_Benin, static_cast<int>(::QLocale::Benin)},
    {sipName_Bermuda, static_cast<int>(::QLocale::Bermuda)},
    {sipName_Bhutan, static_cast<int>(::QLocale::Bhutan)},
    {sipName_Bolivia, static_cast<int>(::QLocale::Bolivia)},
    {sipName_BosniaAndHerzegowina, static_cast<int>(::QLocale::BosniaAndHerzegowina)},
    {sipName_Botswana, static_cast<int>(::QLocale::Botswana)},
    {sipName_BouvetIsland, static_cast<int>(::QLocale::BouvetIsland)},
    {sipName_Brazil, static_cast<int>(::QLocale::Brazil)},
    {sipName_BritishIndianOceanTerritory, static_cast<int>(::QLocale::BritishIndianOceanTerritory)},
    {sipName_Bulgaria, static_cast<int>(::QLocale::Bulgaria)},
    {sipName_BurkinaFaso, static_cast<int>(::QLocale::BurkinaFaso)},
    {sipName_Burundi, static_cast<int>(::QLocale::Burundi)},
    {sipName_Cambodia, static_cast<int>(::QLocale::Cambodia)},
    {sipName_Cameroon, static_cast<int>(::QLocale::Cameroon)},
    {sipName_Canada, static_cast<int>(::QLocale::Canada)},
    {sipName_CapeVerde, static_cast<int>(::QLocale::CapeVerde)},
    {sipName_CaymanIslands, static_cast<int>(::QLocale::CaymanIslands)},
    {sipName_CentralAfricanRepublic, static_cast<int>(::QLocale::CentralAfricanRepublic)},
    {sipName_Chad, static_cast<int>(::QLocale::Chad)},
    {sipName_Chile, static_cast<int>(::QLocale::Chile)},
    {sipName_China, static_cast<int>(::QLocale::China)},
    {sipName_ChristmasIsland, static_cast<int>(::QLocale::ChristmasIsland)},
    {sipName_CocosIslands, static_cast<int>(::QLocale::CocosIslands)},
    {sipName_Colombia, static_cast<int>(::QLocale::Colombia)},
    {sipName_Comoros, static_cast<int>(::QLocale::Comoros)},
    {sipName_DemocraticRepublicOfCongo, static_cast<int>(::QLocale::DemocraticRepublicOfCongo)},
    {sipName_PeoplesRepublicOfCongo, static_cast<int>(::QLocale::PeoplesRepublicOfCongo)},
    {sipName_CookIslands, static_cast<int>(::QLocale::CookIslands)},
    {sipName_CostaRica, static_cast<int>(::QLocale::CostaRica)},
    {sipName_IvoryCoast, static_cast<int>(::QLocale::IvoryCoast)},
    {sipName_Croatia, static_cast<int>(::QLocale::Croatia)},
    {sipName_Cuba, static_cast<int>(::QLocale::Cuba)},
    {sipName_Cyprus, static_cast<int>(::QLocale::Cyprus)},
    {sipName_CzechRepublic, static_cast<int>(::QLocale::CzechRepublic)},
    {sipName_Denmark, static_cast<int>(::QLocale::Denmark)},
    {sipName_Djibouti, static_cast<int>(::QLocale::Djibouti)},
    {sipName_Dominica, static_cast<int>(::QLocale::Dominica)},
    {sipName_DominicanRepublic, static_cast<int>(::QLocale::DominicanRepublic)},
    {sipName_EastTimor, static_cast<int>(::QLocale::EastTimor)},
    {sipName_Ecuador, static_cast<int>(::QLocale::Ecuador)},
    {sipName_Egypt, static_cast<int>(::QLocale::Egypt)},
    {sipName_ElSalvador, static_cast<int>(::QLocale::ElSalvador)},
    {sipName_EquatorialGuinea, static_cast<int>(::QLocale::EquatorialGuinea)},
    {sipName_Eritrea, static_cast<int>(::QLocale::Eritrea)},
    {sipName_Estonia, static_cast<int>(::QLocale::Estonia)},
    {sipName_Ethiopia, static_cast<int>(::QLocale::Ethiopia)},
    {sipName_FalklandIslands, static_cast<int>(::QLocale::FalklandIslands)},
    {sipName_FaroeIslands, static_cast<int>(::QLocale::FaroeIslands)},
    {sipName_Finland, static_cast<int>(::QLocale::Finland)},
    {sipName_France, static_cast<int>(::QLocale::France)},
    {sipName_FrenchGuiana, static_cast<int>(::QLocale::FrenchGuiana)},
    {sipName_FrenchPolynesia, static_cast<int>(::QLocale::FrenchPolynesia)},
    {sipName_FrenchSouthernTerritories, static_cast<int>(::QLocale::FrenchSouthernTerritories)},
    {sipName_Gabon, static_cast<int>(::QLocale::Gabon)},
    {sipName_Gambia, static_cast<int>(::QLocale::Gambia)},
    {sipName_Georgia, static_cast<int>(::QLocale::Georgia)},
    {sipName_Germany, static_cast<int>(::QLocale::Germany)},
    {sipName_Ghana, static_cast<int>(::QLocale::Ghana)},
    {sipName_Gibraltar, static_cast<int>(::QLocale::Gibraltar)},
    {sipName_Greece, static_cast<int>(::QLocale::Greece)},
    {sipName_Greenland, static_cast<int>(::QLocale::Greenland)},
    {sipName_Grenada, static_cast<int>(::QLocale::Grenada)},
    {sipName_Guadeloupe, static_cast<int>(::QLocale::Guadeloupe)},
    {sipName_Guam, static_cast<int>(::QLocale::Guam)},
    {sipName_Guatemala, static_cast<int>(::QLocale::Guatemala)},
    {sipName_Guinea, static_cast<int>(::QLocale::Guinea)},
    {sipName_GuineaBissau, static_cast<int>(::QLocale::GuineaBissau)},
    {sipName_Guyana, static_cast<int>(::QLocale::Guyana)},
    {sipName_Haiti, static_cast<int>(::QLocale::Haiti)},
    {sipName_HeardAndMcDonaldIslands, static_cast<int>(::QLocale::HeardAndMcDonaldIslands)},
    {sipName_Honduras, static_cast<int>(::QLocale::Honduras)},
    {sipName_HongKong, static_cast<int>(::QLocale::HongKong)},
    {sipName_Hungary, static_cast<int>(::QLocale::Hungary)},
    {sipName_Iceland, static_cast<int>(::QLocale::Iceland)},
    {sipName_India, static_cast<int>(::QLocale::India)},
    {sipName_Indonesia, static_cast<int>(::QLocale::Indonesia)},
    {sipName_Iran, static_cast<int>(::QLocale::Iran)},
    {sipName_Iraq, static_cast<int>(::QLocale::Iraq)},
    {sipName_Ireland, static_cast<int>(::QLocale::Ireland)},
    {sipName_Israel, static_cast<int>(::QLocale::Israel)},
    {sipName_Italy, static_cast<int>(::QLocale::Italy)},
    {sipName_Jamaica, static_cast<int>(::QLocale::Jamaica)},
    {sipName_Japan, static_cast<int>(::QLocale::Japan)},
    {sipName_Jordan, static_cast<int>(::QLocale::Jordan)},
    {sipName_Kazakhstan, static_cast<int>(::QLocale::Kazakhstan)},
    {sipName_Kenya, static_cast<int>(::QLocale::Kenya)},
    {sipName_Kiribati, static_cast<int>(::QLocale::Kiribati)},
    {sipName_DemocraticRepublicOfKorea, static_cast<int>(::QLocale::DemocraticRepublicOfKorea)},
    {sipName_RepublicOfKorea, static_cast<int>(::QLocale::RepublicOfKorea)},
    {sipName_Kuwait, static_cast<int>(::QLocale::Kuwait)},
    {sipName_Kyrgyzstan, static_cast<int>(::QLocale::Kyrgyzstan)},
    {sipName_Latvia, static_cast<int>(::QLocale::Latvia)},
    {sipName_Lebanon, static_cast<int>(::QLocale::Lebanon)},
    {sipName_Lesotho, static_cast<int>(::QLocale::Lesotho)},
    {sipName_Liberia, static_cast<int>(::QLocale::Liberia)},
    {sipName_Liechtenstein, static_cast<int>(::QLocale::Liechtenstein)},
    {sipName_Lithuania, static_cast<int>(::QLocale::Lithuania)},
    {sipName_Luxembourg, static_cast<int>(::QLocale::Luxembourg)},
    {sipName_Macau, static_cast<int>(::QLocale::Macau)},
    {sipName_Macedonia, static_cast<int>(::QLocale::Macedonia)},
    {sipName_Madagascar, static_cast<int>(::QLocale::Madagascar)},
    {sipName_Malawi, static_cast<int>(::QLocale::Malawi)},
    {sipName_Malaysia, static_cast<int>(::QLocale::Malaysia)},
    {sipName_Maldives, static_cast<int>(::QLocale::Maldives)},
    {sipName_Mali, static_cast<int>(::QLocale::Mali)},
    {sipName_Malta, static_cast<int>(::QLocale::Malta)},
    {sipName_MarshallIslands, static_cast<int>(::QLocale::MarshallIslands)},
    {sipName_Martinique, static_cast<int>(::QLocale::Martinique)},
    {sipName_Mauritania, static_cast<int>(::QLocale::Mauritania)},
    {sipName_Mauritius, static_cast<int>(::QLocale::Mauritius)},
    {sipName_Mayotte, static_cast<int>(::QLocale::Mayotte)},
    {sipName_Mexico, static_cast<int>(::QLocale::Mexico)},
    {sipName_Micronesia, static_cast<int>(::QLocale::Micronesia)},
    {sipName_Moldova, static_cast<int>(::QLocale::Moldova)},
    {sipName_Monaco, static_cast<int>(::QLocale::Monaco)},
    {sipName_Mongolia, static_cast<int>(::QLocale::Mongolia)},
    {sipName_Montserrat, static_cast<int>(::QLocale::Montserrat)},
    {sipName_Morocco, static_cast<int>(::QLocale::Morocco)},
    {sipName_Mozambique, static_cast<int>(::QLocale::Mozambique)},
    {sipName_Myanmar, static_cast<int>(::QLocale::Myanmar)},
    {sipName_Namibia, static_cast<int>(::QLocale::Namibia)},
    {sipName_NauruCountry, static_cast<int>(::QLocale::NauruCountry)},
    {sipName_Nepal, static_cast<int>(::QLocale::Nepal)},
    {sipName_Netherlands, static_cast<int>(::QLocale::Netherlands)},
    {sipName_NewCaledonia, static_cast<int>(::QLocale::NewCaledonia)},
    {sipName_NewZealand, static_cast<int>(::QLocale::NewZealand)},
    {sipName_Nicaragua, static_cast<int>(::QLocale::Nicaragua)},
    {sipName_Niger, static_cast<int>(::QLocale::Niger)},
    {sipName_Nigeria, static_cast<int>(::QLocale::Nigeria)},
    {sipName_Niue, static_cast<int>(::QLocale::Niue)},
    {sipName_NorfolkIsland, static_cast<int>(::QLocale::NorfolkIsland)},
    {sipName_NorthernMarianaIslands, static_cast<int>(::QLocale::NorthernMarianaIslands)},
    {sipName_Norway, static_cast<int>(::QLocale::Norway)},
    {sipName_Oman, static_cast<int>(::QLocale::Oman)},
    {sipName_Pakistan, static_cast<int>(::QLocale::Pakistan)},
    {sipName_Palau, static_cast<int>(::QLocale::Palau)},
    {sipName_Panama, static_cast<int>(::QLocale::Panama)},
    {sipName_PapuaNewGuinea, static_cast<int>(::QLocale::PapuaNewGuinea)},
    {sipName_Paraguay, static_cast<int>(::QLocale::Paraguay)},
    {sipName_Peru, static_cast<int>(::QLocale::Peru)},
    {sipName_Philippines, static_cast<int>(::QLocale::Philippines)},
    {sipName_Pitcairn, static_cast<int>(::QLocale::Pitcairn)},
    {sipName_Poland, static_cast<int>(::QLocale::Poland)},
    {sipName_Portugal, static_cast<int>(::QLocale::Portugal)},
    {sipName_PuertoRico, static_cast<int>(::QLocale::PuertoRico)},
    {sipName_Qatar, static_cast<int>(::QLocale::Qatar)},
    {sipName_Reunion, static_cast<int>(::QLocale::Reunion)},
    {sipName_Romania, static_cast<int>(::QLocale::Romania)},
    {sipName_RussianFederation, static_cast<int>(::QLocale::RussianFederation)},
    {sipName_Rwanda, static_cast<int>(::QLocale::Rwanda)},
    {sipName_SaintKittsAndNevis, static_cast<int>(::QLocale::SaintKittsAndNevis)},
    {sipName_Samoa, static_cast<int>(::QLocale::Samoa)},
    {sipName_SanMarino, static_cast<int>(::QLocale::SanMarino)},
    {sipName_SaoTomeAndPrincipe, static_cast<int>(::QLocale::SaoTomeAndPrincipe)},
    {sipName_SaudiArabia, static_cast<int>(::QLocale::SaudiArabia)},
    {sipName_Senegal, static_cast<int>(::QLocale::Senegal)},
    {sipName_Seychelles, static_cast<int>(::QLocale::Seychelles)},
    {sipName_SierraLeone, static_cast<int>(::QLocale::SierraLeone)},
    {sipName_Singapore, static_cast<int>(::QLocale::Singapore)},
    {sipName_Slovakia, static_cast<int>(::QLocale::Slovakia)},
    {sipName_Slovenia, static_cast<int>(::QLocale::Slovenia)},
    {sipName_SolomonIslands, static_cast<int>(::QLocale::SolomonIslands)},
    {sipName_Somalia, static_cast<int>(::QLocale::Somalia)},
    {sipName_SouthAfrica, static_cast<int>(::QLocale::SouthAfrica)},
    {sipName_SouthGeorgiaAndTheSouthSandwichIslands, static_cast<int>(::QLocale::SouthGeorgiaAndTheSouthSandwichIslands)},
    {sipName_Spain, static_cast<int>(::QLocale::Spain)},
    {sipName_SriLanka, static_cast<int>(::QLocale::SriLanka)},
    {sipName_Sudan, static_cast<int>(::QLocale::Sudan)},
    {sipName_Suriname, static_cast<int>(::QLocale::Suriname)},
    {sipName_SvalbardAndJanMayenIslands, static_cast<int>(::QLocale::SvalbardAndJanMayenIslands)},
    {sipName_Swaziland, static_cast<int>(::QLocale::Swaziland)},
    {sipName_Sweden, static_cast<int>(::QLocale::Sweden)},
    {sipName_Switzerland, static_cast<int>(::QLocale::Switzerland)},
    {sipName_SyrianArabRepublic, static_cast<int>(::QLocale::SyrianArabRepublic)},
    {sipName_Taiwan, static_cast<int>(::QLocale::Taiwan)},
    {sipName_Tajikistan, static_cast<int>(::QLocale::Tajikistan)},
    {sipName_Tanzania, static_cast<int>(::QLocale::Tanzania)},
    {sipName_Thailand, static_cast<int>(::QLocale::Thailand)},
    {sipName_Togo, static_cast<int>(::QLocale::Togo)},
    {sipName_TrinidadAndTobago, static_cast<int>(::QLocale::TrinidadAndTobago)},
    {sipName_Tunisia, static_cast<int>(::QLocale::Tunisia)},
    {sipName_Turkey, static_cast<int>(::QLocale::Turkey)},
    {sipName_Turkmenistan, static_cast<int>(::QLocale::Turkmenistan)},
    {sipName_TurksAndCaicosIslands, static_cast<int>(::QLocale::TurksAndCaicosIslands)},
    {sipName_Uganda, static_cast<int>(::QLocale::Uganda)},
    {sipName_Ukraine, static_cast<int>(::QLocale::Ukraine)},
    {sipName_UnitedArabEmirates, static_cast<int>(::QLocale::UnitedArabEmirates)},
    {sipName_UnitedKingdom, static_cast<int>(::QLocale::UnitedKingdom)},
    {sipName_UnitedStates, static_cast<int>(::QLocale::UnitedStates)},
    {sipName_UnitedStatesMinorOutlyingIslands, static_cast<int>(::QLocale::UnitedStatesMinorOutlyingIslands)},
    {sipName_Uruguay, static_cast<int>(::QLocale::Uruguay)},
    {sipName_Uzbekistan, static_cast<int>(::QLocale::Uzbekistan)},
    {sipName_Vanuatu, static_cast<int>(::QLocale::Vanuatu)},
    {sipName_VaticanCityState, static_cast<int>(::QLocale::VaticanCityState)},
    {sipName_Venezuela, static_cast<int>(::QLocale::Venezuela)},
    {sipName_BritishVirginIslands, static_cast<int>(::QLocale::BritishVirginIslands)},
    {sipName_WallisAndFutunaIslands, static_cast<int>(::QLocale::WallisAndFutunaIslands)},
    {sipName_WesternSahara, static_cast<int>(::QLocale::WesternSahara)},
    {sipName_Yemen, static_cast<int>(::QLocale::Yemen)},
    {sipName_Zambia, static_cast<int>(::QLocale::Zambia)},
    {sipName_Zimbabwe, static_cast<int>(::QLocale::Zimbabwe)},
    {sipName_Montenegro, static_cast<int>(::QLocale::Montenegro)},
    {sipName_Serbia, static_cast<int>(::QLocale::Serbia)},
    {sipName_SaintBarthelemy, static_cast<int>(::QLocale::SaintBarthelemy)},
    {sipName_SaintMartin, static_cast<int>(::QLocale::SaintMartin)},
    {sipName_LatinAmericaAndTheCaribbean, static_cast<int>(::QLocale::LatinAmericaAndTheCaribbean)},
    {sipName_LastCountry, static_cast<int>(::QLocale::LastCountry)},
    {sipName_Brunei, static_cast<int>(::QLocale::Brunei)},
    {sipName_CongoKinshasa, static_cast<int>(::QLocale::CongoKinshasa)},
    {sipName_CongoBrazzaville, static_cast<int>(::QLocale::CongoBrazzaville)},
    {sipName_Fiji, static_cast<int>(::QLocale::Fiji)},
    {sipName_Guernsey, static_cast<int>(::QLocale::Guernsey)},
    {sipName_NorthKorea, static_cast<int>(::QLocale::NorthKorea)},
    {sipName_SouthKorea, static_cast<int>(::QLocale::SouthKorea)},
    {sipName_Laos, static_cast<int>(::QLocale::Laos)},
    {sipName_Libya, static_cast<int>(::QLocale::Libya)},
    {sipName_CuraSao, static_cast<int>(::QLocale::CuraSao)},
    {sipName_PalestinianTerritories, static_cast<int>(::QLocale::PalestinianTerritories)},
    {sipName_Russia, static_cast<int>(::QLocale::Russia)},
    {sipName_SaintLucia, static_cast<int>(::QLocale::SaintLucia)},
    {sipName_SaintVincentAndTheGrenadines, static_cast<int>(::QLocale::SaintVincentAndTheGrenadines)},
    {sipName_SaintHelena, static_cast<int>(::QLocale::SaintHelena)},
    {sipName_SaintPierreAndMiquelon, static_cast<int>(::QLocale::SaintPierreAndMiquelon)},
    {sipName_Syria, static_cast<int>(::QLocale::Syria)},
    {sipName_Tonga, static_cast<int>(::QLocale::Tonga)},
    {sipName_Vietnam, static_cast<int>(::QLocale::Vietnam)},
    {sipName_UnitedStatesVirginIslands, static_cast<int>(::QLocale::UnitedStatesVirginIslands)},
    {sipName_CanaryIslands, static_cast<int>(::QLocale::CanaryIslands)},
    {sipName_ClippertonIsland, static_cast<int>(::QLocale::ClippertonIsland)},
    {sipName_AscensionIsland, static_cast<int>(::QLocale::AscensionIsland)},
    {sipName_AlandIslands, static_cast<int>(::QLocale::AlandIslands)},
    {sipName_DiegoGarcia, static_cast<int>(::QLocale::DiegoGarcia)},
    {sipName_CeutaAndMelilla, static_cast<int>(::QLocale::CeutaAndMelilla)},
    {sipName_IsleOfMan, static_cast<int>(::QLocale::IsleOfMan)},
    {sipName_Jersey, static_cast<int>(::QLocale::Jersey)},
    {sipName_TristanDaCunha, static_cast<int>(::QLocale::TristanDaCunha)},
    {sipName_SouthSudan, static_cast<int>(::QLocale::SouthSudan)},
    {sipName_Bonaire, static_cast<int>(::QLocale::Bonaire)},
    {sipName_SintMaarten, static_cast<int>(::QLocale::SintMaarten)},
    {sipName_Kosovo, static_cast<int>(::QLocale::Kosovo)},
    {sipName_TokelauCountry, static_cast<int>(::QLocale::TokelauCountry)},
    {sipName_TuvaluCountry, static_cast<int>(::QLocale::TuvaluCountry)},
    {sipName_EuropeanUnion, static_cast<int>(::QLocale::EuropeanUnion)},
    {sipName_OutlyingOceania, static_cast<int>(::QLocale::OutlyingOceania)},
    {sipName_LatinAmerica, static_cast<int>(::QLocale::LatinAmerica)},
    {sipName_World, static_cast<int>(::QLocale::World)},
    {sipName_Europe, static_cast<int>(::QLocale::Europe)},
    {sipName_BosniaAndHerzegovina, static_cast<int>(::QLocale::BosniaAndHerzegovina)},
    {sipName_CaribbeanNetherlands, static_cast<int>(::QLocale::CaribbeanNetherlands)},
    {sipName_Curacao, static_cast<int>(::QLocale::Curacao)},
    {sipName_Czechia, static_cast<int>(::QLocale::Czechia)},
    {sipName_Eswatini, static_cast<int>(::QLocale::Eswatini)},
    {sipName_Macao, static_cast<int>(::QLocale::Macao)},
    {sipName_SaintVincentAndGrenadines, static_cast<int>(::QLocale::SaintVincentAndGrenadines)},
    {sipName_SouthGeorgiaAndSouthSandwichIslands, static_cast<int>(::QLocale::SouthGeorgiaAndSouthSandwichIslands)},
    {sipName_SvalbardAndJanMayen, static_cast<int>(::QLocale::SvalbardAndJanMayen)},
    {sipName_TimorLeste, static_cast<int>(::QLocale::TimorLeste)},
    {sipName_UnitedStatesOutlyingIslands, static_cast<int>(::QLocale::UnitedStatesOutlyingIslands)},
    {sipName_VaticanCity, static_cast<int>(::QLocale::VaticanCity)},
    {sipName_WallisAndFutuna, static_cast<int>(::QLocale::WallisAndFutuna)},
    {sipName_NauruTerritory, static_cast<int>(::QLocale::NauruTerritory)},
    {sipName_TokelauTerritory, static_cast<int>(::QLocale::TokelauTerritory)},
    {sipName_TuvaluTerritory, static_cast<int>(::QLocale::TuvaluTerritory)},
    {sipName_CurrencyIsoCode, static_cast<int>(::QLocale::CurrencyIsoCode)},
    {sipName_CurrencySymbol, static_cast<int>(::QLocale::CurrencySymbol)},
    {sipName_CurrencyDisplayName, static_cast<int>(::QLocale::CurrencyDisplayName)},
    {sipName_DataSizeIecFormat, static_cast<int>(::QLocale::DataSizeIecFormat)},
    {sipName_DataSizeTraditionalFormat, static_cast<int>(::QLocale::DataSizeTraditionalFormat)},
    {sipName_DataSizeSIFormat, static_cast<int>(::QLocale::DataSizeSIFormat)},
    {sipName_FloatingPointShortest, static_cast<int>(::QLocale::FloatingPointShortest)},
    {sipName_LongFormat, static_cast<int>(::QLocale::LongFormat)},
    {sipName_ShortFormat, static_cast<int>(::QLocale::ShortFormat)},
    {sipName_NarrowFormat, static_cast<int>(::QLocale::NarrowFormat)},
    {sipName_C, static_cast<int>(::QLocale::C)},
    {sipName_Abkhazian, static_cast<int>(::QLocale::Abkhazian)},
    {sipName_Afan, static_cast<int>(::QLocale::Afan)},
    {sipName_Afar, static_cast<int>(::QLocale::Afar)},
    {sipName_Afrikaans, static_cast<int>(::QLocale::Afrikaans)},
    {sipName_Albanian, static_cast<int>(::QLocale::Albanian)},
    {sipName_Amharic, static_cast<int>(::QLocale::Amharic)},
    {sipName_Arabic, static_cast<int>(::QLocale::Arabic)},
    {sipName_Armenian, static_cast<int>(::QLocale::Armenian)},
    {sipName_Assamese, static_cast<int>(::QLocale::Assamese)},
    {sipName_Aymara, static_cast<int>(::QLocale::Aymara)},
    {sipName_Azerbaijani, static_cast<int>(::QLocale::Azerbaijani)},
    {sipName_Bashkir, static_cast<int>(::QLocale::Bashkir)},
    {sipName_Basque, static_cast<int>(::QLocale::Basque)},
    {sipName_Bengali, static_cast<int>(::QLocale::Bengali)},
    {sipName_Bhutani, static_cast<int>(::QLocale::Bhutani)},
    {sipName_Bislama, static_cast<int>(::QLocale::Bislama)},
    {sipName_Breton, static_cast<int>(::QLocale::Breton)},
    {sipName_Bulgarian, static_cast<int>(::QLocale::Bulgarian)},
    {sipName_Burmese, static_cast<int>(::QLocale::Burmese)},
    {sipName_Byelorussian, static_cast<int>(::QLocale::Byelorussian)},
    {sipName_Cambodian, static_cast<int>(::QLocale::Cambodian)},
    {sipName_Catalan, static_cast<int>(::QLocale::Catalan)},
    {sipName_Chinese, static_cast<int>(::QLocale::Chinese)},
    {sipName_Corsican, static_cast<int>(::QLocale::Corsican)},
    {sipName_Croatian, static_cast<int>(::QLocale::Croatian)},
    {sipName_Czech, static_cast<int>(::QLocale::Czech)},
    {sipName_Danish, static_cast<int>(::QLocale::Danish)},
    {sipName_Dutch, static_cast<int>(::QLocale::Dutch)},
    {sipName_English, static_cast<int>(::QLocale::English)},
    {sipName_Esperanto, static_cast<int>(::QLocale::Esperanto)},
    {sipName_Estonian, static_cast<int>(::QLocale::Estonian)},
    {sipName_Faroese, static_cast<int>(::QLocale::Faroese)},
    {sipName_Finnish, static_cast<int>(::QLocale::Finnish)},
    {sipName_French, static_cast<int>(::QLocale::French)},
    {sipName_Frisian, static_cast<int>(::QLocale::Frisian)},
    {sipName_Gaelic, static_cast<int>(::QLocale::Gaelic)},
    {sipName_Galician, static_cast<int>(::QLocale::Galician)},
    {sipName_Georgian, static_cast<int>(::QLocale::Georgian)},
    {sipName_German, static_cast<int>(::QLocale::German)},
    {sipName_Greek, static_cast<int>(::QLocale::Greek)},
    {sipName_Greenlandic, static_cast<int>(::QLocale::Greenlandic)},
    {sipName_Guarani, static_cast<int>(::QLocale::Guarani)},
    {sipName_Gujarati, static_cast<int>(::QLocale::Gujarati)},
    {sipName_Hausa, static_cast<int>(::QLocale::Hausa)},
    {sipName_Hebrew, static_cast<int>(::QLocale::Hebrew)},
    {sipName_Hindi, static_cast<int>(::QLocale::Hindi)},
    {sipName_Hungarian, static_cast<int>(::QLocale::Hungarian)},
    {sipName_Icelandic, static_cast<int>(::QLocale::Icelandic)},
    {sipName_Indonesian, static_cast<int>(::QLocale::Indonesian)},
    {sipName_Interlingua, static_cast<int>(::QLocale::Interlingua)},
    {sipName_Interlingue, static_cast<int>(::QLocale::Interlingue)},
    {sipName_Inuktitut, static_cast<int>(::QLocale::Inuktitut)},
    {sipName_Inupiak, static_cast<int>(::QLocale::Inupiak)},
    {sipName_Irish, static_cast<int>(::QLocale::Irish)},
    {sipName_Italian, static_cast<int>(::QLocale::Italian)},
    {sipName_Japanese, static_cast<int>(::QLocale::Japanese)},
    {sipName_Javanese, static_cast<int>(::QLocale::Javanese)},
    {sipName_Kannada, static_cast<int>(::QLocale::Kannada)},
    {sipName_Kashmiri, static_cast<int>(::QLocale::Kashmiri)},
    {sipName_Kazakh, static_cast<int>(::QLocale::Kazakh)},
    {sipName_Kinyarwanda, static_cast<int>(::QLocale::Kinyarwanda)},
    {sipName_Kirghiz, static_cast<int>(::QLocale::Kirghiz)},
    {sipName_Korean, static_cast<int>(::QLocale::Korean)},
    {sipName_Kurdish, static_cast<int>(::QLocale::Kurdish)},
    {sipName_Kurundi, static_cast<int>(::QLocale::Kurundi)},
    {sipName_Latin, static_cast<int>(::QLocale::Latin)},
    {sipName_Latvian, static_cast<int>(::QLocale::Latvian)},
    {sipName_Lingala, static_cast<int>(::QLocale::Lingala)},
    {sipName_Lithuanian, static_cast<int>(::QLocale::Lithuanian)},
    {sipName_Macedonian, static_cast<int>(::QLocale::Macedonian)},
    {sipName_Malagasy, static_cast<int>(::QLocale::Malagasy)},
    {sipName_Malay, static_cast<int>(::QLocale::Malay)},
    {sipName_Malayalam, static_cast<int>(::QLocale::Malayalam)},
    {sipName_Maltese, static_cast<int>(::QLocale::Maltese)},
    {sipName_Maori, static_cast<int>(::QLocale::Maori)},
    {sipName_Marathi, static_cast<int>(::QLocale::Marathi)},
    {sipName_Mongolian, static_cast<int>(::QLocale::Mongolian)},
    {sipName_NauruLanguage, static_cast<int>(::QLocale::NauruLanguage)},
    {sipName_Nepali, static_cast<int>(::QLocale::Nepali)},
    {sipName_Occitan, static_cast<int>(::QLocale::Occitan)},
    {sipName_Oriya, static_cast<int>(::QLocale::Oriya)},
    {sipName_Pashto, static_cast<int>(::QLocale::Pashto)},
    {sipName_Persian, static_cast<int>(::QLocale::Persian)},
    {sipName_Polish, static_cast<int>(::QLocale::Polish)},
    {sipName_Portuguese, static_cast<int>(::QLocale::Portuguese)},
    {sipName_Punjabi, static_cast<int>(::QLocale::Punjabi)},
    {sipName_Quechua, static_cast<int>(::QLocale::Quechua)},
    {sipName_RhaetoRomance, static_cast<int>(::QLocale::RhaetoRomance)},
    {sipName_Romanian, static_cast<int>(::QLocale::Romanian)},
    {sipName_Russian, static_cast<int>(::QLocale::Russian)},
    {sipName_Samoan, static_cast<int>(::QLocale::Samoan)},
    {sipName_Sanskrit, static_cast<int>(::QLocale::Sanskrit)},
    {sipName_Serbian, static_cast<int>(::QLocale::Serbian)},
    {sipName_Shona, static_cast<int>(::QLocale::Shona)},
    {sipName_Sindhi, static_cast<int>(::QLocale::Sindhi)},
    {sipName_Slovak, static_cast<int>(::QLocale::Slovak)},
    {sipName_Slovenian, static_cast<int>(::QLocale::Slovenian)},
    {sipName_Somali, static_cast<int>(::QLocale::Somali)},
    {sipName_Spanish, static_cast<int>(::QLocale::Spanish)},
    {sipName_Sundanese, static_cast<int>(::QLocale::Sundanese)},
    {sipName_Swahili, static_cast<int>(::QLocale::Swahili)},
    {sipName_Swedish, static_cast<int>(::QLocale::Swedish)},
    {sipName_Tajik, static_cast<int>(::QLocale::Tajik)},
    {sipName_Tamil, static_cast<int>(::QLocale::Tamil)},
    {sipName_Tatar, static_cast<int>(::QLocale::Tatar)},
    {sipName_Telugu, static_cast<int>(::QLocale::Telugu)},
    {sipName_Thai, static_cast<int>(::QLocale::Thai)},
    {sipName_Tibetan, static_cast<int>(::QLocale::Tibetan)},
    {sipName_Tigrinya, static_cast<int>(::QLocale::Tigrinya)},
    {sipName_Tsonga, static_cast<int>(::QLocale::Tsonga)},
    {sipName_Turkish, static_cast<int>(::QLocale::Turkish)},
    {sipName_Turkmen, static_cast<int>(::QLocale::Turkmen)},
    {sipName_Uigur, static_cast<int>(::QLocale::Uigur)},
    {sipName_Ukrainian, static_cast<int>(::QLocale::Ukrainian)},
    {sipName_Urdu, static_cast<int>(::QLocale::Urdu)},
    {sipName_Uzbek, static_cast<int>(::QLocale::Uzbek)},
    {sipName_Vietnamese, static_cast<int>(::QLocale::Vietnamese)},
    {sipName_Volapuk, static_cast<int>(::QLocale::Volapuk)},
    {sipName_Welsh, static_cast<int>(::QLocale::Welsh)},
    {sipName_Wolof, static_cast<int>(::QLocale::Wolof)},
    {sipName_Xhosa, static_cast<int>(::QLocale::Xhosa)},
    {sipName_Yiddish, static_cast<int>(::QLocale::Yiddish)},
    {sipName_Yoruba, static_cast<int>(::QLocale::Yoruba)},
    {sipName_Zhuang, static_cast<int>(::QLocale::Zhuang)},
    {sipName_Zulu, static_cast<int>(::QLocale::Zulu)},
    {sipName_Bosnian, static_cast<int>(::QLocale::Bosnian)},
    {sipName_Divehi, static_cast<int>(::QLocale::Divehi)},
    {sipName_Manx, static_cast<int>(::QLocale::Manx)},
    {sipName_Cornish, static_cast<int>(::QLocale::Cornish)},
    {sipName_LastLanguage, static_cast<int>(::QLocale::LastLanguage)},
    {sipName_NorwegianBokmal, static_cast<int>(::QLocale::NorwegianBokmal)},
    {sipName_NorwegianNynorsk, static_cast<int>(::QLocale::NorwegianNynorsk)},
    {sipName_Akan, static_cast<int>(::QLocale::Akan)},
    {sipName_Konkani, static_cast<int>(::QLocale::Konkani)},
    {sipName_Ga, static_cast<int>(::QLocale::Ga)},
    {sipName_Igbo, static_cast<int>(::QLocale::Igbo)},
    {sipName_Kamba, static_cast<int>(::QLocale::Kamba)},
    {sipName_Syriac, static_cast<int>(::QLocale::Syriac)},
    {sipName_Blin, static_cast<int>(::QLocale::Blin)},
    {sipName_Geez, static_cast<int>(::QLocale::Geez)},
    {sipName_Koro, static_cast<int>(::QLocale::Koro)},
    {sipName_Sidamo, static_cast<int>(::QLocale::Sidamo)},
    {sipName_Atsam, static_cast<int>(::QLocale::Atsam)},
    {sipName_Tigre, static_cast<int>(::QLocale::Tigre)},
    {sipName_Jju, static_cast<int>(::QLocale::Jju)},
    {sipName_Friulian, static_cast<int>(::QLocale::Friulian)},
    {sipName_Venda, static_cast<int>(::QLocale::Venda)},
    {sipName_Ewe, static_cast<int>(::QLocale::Ewe)},
    {sipName_Walamo, static_cast<int>(::QLocale::Walamo)},
    {sipName_Hawaiian, static_cast<int>(::QLocale::Hawaiian)},
    {sipName_Tyap, static_cast<int>(::QLocale::Tyap)},
    {sipName_Chewa, static_cast<int>(::QLocale::Chewa)},
    {sipName_Filipino, static_cast<int>(::QLocale::Filipino)},
    {sipName_SwissGerman, static_cast<int>(::QLocale::SwissGerman)},
    {sipName_SichuanYi, static_cast<int>(::QLocale::SichuanYi)},
    {sipName_Kpelle, static_cast<int>(::QLocale::Kpelle)},
    {sipName_LowGerman, static_cast<int>(::QLocale::LowGerman)},
    {sipName_SouthNdebele, static_cast<int>(::QLocale::SouthNdebele)},
    {sipName_NorthernSotho, static_cast<int>(::QLocale::NorthernSotho)},
    {sipName_NorthernSami, static_cast<int>(::QLocale::NorthernSami)},
    {sipName_Taroko, static_cast<int>(::QLocale::Taroko)},
    {sipName_Gusii, static_cast<int>(::QLocale::Gusii)},
    {sipName_Taita, static_cast<int>(::QLocale::Taita)},
    {sipName_Fulah, static_cast<int>(::QLocale::Fulah)},
    {sipName_Kikuyu, static_cast<int>(::QLocale::Kikuyu)},
    {sipName_Samburu, static_cast<int>(::QLocale::Samburu)},
    {sipName_Sena, static_cast<int>(::QLocale::Sena)},
    {sipName_NorthNdebele, static_cast<int>(::QLocale::NorthNdebele)},
    {sipName_Rombo, static_cast<int>(::QLocale::Rombo)},
    {sipName_Tachelhit, static_cast<int>(::QLocale::Tachelhit)},
    {sipName_Kabyle, static_cast<int>(::QLocale::Kabyle)},
    {sipName_Nyankole, static_cast<int>(::QLocale::Nyankole)},
    {sipName_Bena, static_cast<int>(::QLocale::Bena)},
    {sipName_Vunjo, static_cast<int>(::QLocale::Vunjo)},
    {sipName_Bambara, static_cast<int>(::QLocale::Bambara)},
    {sipName_Embu, static_cast<int>(::QLocale::Embu)},
    {sipName_Cherokee, static_cast<int>(::QLocale::Cherokee)},
    {sipName_Morisyen, static_cast<int>(::QLocale::Morisyen)},
    {sipName_Makonde, static_cast<int>(::QLocale::Makonde)},
    {sipName_Langi, static_cast<int>(::QLocale::Langi)},
    {sipName_Ganda, static_cast<int>(::QLocale::Ganda)},
    {sipName_Bemba, static_cast<int>(::QLocale::Bemba)},
    {sipName_Kabuverdianu, static_cast<int>(::QLocale::Kabuverdianu)},
    {sipName_Meru, static_cast<int>(::QLocale::Meru)},
    {sipName_Kalenjin, static_cast<int>(::QLocale::Kalenjin)},
    {sipName_Nama, static_cast<int>(::QLocale::Nama)},
    {sipName_Machame, static_cast<int>(::QLocale::Machame)},
    {sipName_Colognian, static_cast<int>(::QLocale::Colognian)},
    {sipName_Masai, static_cast<int>(::QLocale::Masai)},
    {sipName_Soga, static_cast<int>(::QLocale::Soga)},
    {sipName_Luyia, static_cast<int>(::QLocale::Luyia)},
    {sipName_Asu, static_cast<int>(::QLocale::Asu)},
    {sipName_Teso, static_cast<int>(::QLocale::Teso)},
    {sipName_Saho, static_cast<int>(::QLocale::Saho)},
    {sipName_KoyraChiini, static_cast<int>(::QLocale::KoyraChiini)},
    {sipName_Rwa, static_cast<int>(::QLocale::Rwa)},
    {sipName_Luo, static_cast<int>(::QLocale::Luo)},
    {sipName_Chiga, static_cast<int>(::QLocale::Chiga)},
    {sipName_CentralMoroccoTamazight, static_cast<int>(::QLocale::CentralMoroccoTamazight)},
    {sipName_KoyraboroSenni, static_cast<int>(::QLocale::KoyraboroSenni)},
    {sipName_Shambala, static_cast<int>(::QLocale::Shambala)},
    {sipName_AnyLanguage, static_cast<int>(::QLocale::AnyLanguage)},
    {sipName_Rundi, static_cast<int>(::QLocale::Rundi)},
    {sipName_Bodo, static_cast<int>(::QLocale::Bodo)},
    {sipName_Aghem, static_cast<int>(::QLocale::Aghem)},
    {sipName_Basaa, static_cast<int>(::QLocale::Basaa)},
    {sipName_Zarma, static_cast<int>(::QLocale::Zarma)},
    {sipName_Duala, static_cast<int>(::QLocale::Duala)},
    {sipName_JolaFonyi, static_cast<int>(::QLocale::JolaFonyi)},
    {sipName_Ewondo, static_cast<int>(::QLocale::Ewondo)},
    {sipName_Bafia, static_cast<int>(::QLocale::Bafia)},
    {sipName_LubaKatanga, static_cast<int>(::QLocale::LubaKatanga)},
    {sipName_MakhuwaMeetto, static_cast<int>(::QLocale::MakhuwaMeetto)},
    {sipName_Mundang, static_cast<int>(::QLocale::Mundang)},
    {sipName_Kwasio, static_cast<int>(::QLocale::Kwasio)},
    {sipName_Nuer, static_cast<int>(::QLocale::Nuer)},
    {sipName_Sakha, static_cast<int>(::QLocale::Sakha)},
    {sipName_Sangu, static_cast<int>(::QLocale::Sangu)},
    {sipName_Tasawaq, static_cast<int>(::QLocale::Tasawaq)},
    {sipName_Vai, static_cast<int>(::QLocale::Vai)},
    {sipName_Walser, static_cast<int>(::QLocale::Walser)},
    {sipName_Yangben, static_cast<int>(::QLocale::Yangben)},
    {sipName_Oromo, static_cast<int>(::QLocale::Oromo)},
    {sipName_Dzongkha, static_cast<int>(::QLocale::Dzongkha)},
    {sipName_Belarusian, static_cast<int>(::QLocale::Belarusian)},
    {sipName_Khmer, static_cast<int>(::QLocale::Khmer)},
    {sipName_Fijian, static_cast<int>(::QLocale::Fijian)},
    {sipName_WesternFrisian, static_cast<int>(::QLocale::WesternFrisian)},
    {sipName_Lao, static_cast<int>(::QLocale::Lao)},
    {sipName_Marshallese, static_cast<int>(::QLocale::Marshallese)},
    {sipName_Romansh, static_cast<int>(::QLocale::Romansh)},
    {sipName_Sango, static_cast<int>(::QLocale::Sango)},
    {sipName_Ossetic, static_cast<int>(::QLocale::Ossetic)},
    {sipName_SouthernSotho, static_cast<int>(::QLocale::SouthernSotho)},
    {sipName_Tswana, static_cast<int>(::QLocale::Tswana)},
    {sipName_Sinhala, static_cast<int>(::QLocale::Sinhala)},
    {sipName_Swati, static_cast<int>(::QLocale::Swati)},
    {sipName_Sardinian, static_cast<int>(::QLocale::Sardinian)},
    {sipName_Tongan, static_cast<int>(::QLocale::Tongan)},
    {sipName_Tahitian, static_cast<int>(::QLocale::Tahitian)},
    {sipName_Nyanja, static_cast<int>(::QLocale::Nyanja)},
    {sipName_Avaric, static_cast<int>(::QLocale::Avaric)},
    {sipName_Chamorro, static_cast<int>(::QLocale::Chamorro)},
    {sipName_Chechen, static_cast<int>(::QLocale::Chechen)},
    {sipName_Church, static_cast<int>(::QLocale::Church)},
    {sipName_Chuvash, static_cast<int>(::QLocale::Chuvash)},
    {sipName_Cree, static_cast<int>(::QLocale::Cree)},
    {sipName_Haitian, static_cast<int>(::QLocale::Haitian)},
    {sipName_Herero, static_cast<int>(::QLocale::Herero)},
    {sipName_HiriMotu, static_cast<int>(::QLocale::HiriMotu)},
    {sipName_Kanuri, static_cast<int>(::QLocale::Kanuri)},
    {sipName_Komi, static_cast<int>(::QLocale::Komi)},
    {sipName_Kongo, static_cast<int>(::QLocale::Kongo)},
    {sipName_Kwanyama, static_cast<int>(::QLocale::Kwanyama)},
    {sipName_Limburgish, static_cast<int>(::QLocale::Limburgish)},
    {sipName_Luxembourgish, static_cast<int>(::QLocale::Luxembourgish)},
    {sipName_Navaho, static_cast<int>(::QLocale::Navaho)},
    {sipName_Ndonga, static_cast<int>(::QLocale::Ndonga)},
    {sipName_Ojibwa, static_cast<int>(::QLocale::Ojibwa)},
    {sipName_Pali, static_cast<int>(::QLocale::Pali)},
    {sipName_Walloon, static_cast<int>(::QLocale::Walloon)},
    {sipName_Avestan, static_cast<int>(::QLocale::Avestan)},
    {sipName_Asturian, static_cast<int>(::QLocale::Asturian)},
    {sipName_Ngomba, static_cast<int>(::QLocale::Ngomba)},
    {sipName_Kako, static_cast<int>(::QLocale::Kako)},
    {sipName_Meta, static_cast<int>(::QLocale::Meta)},
    {sipName_Ngiemboon, static_cast<int>(::QLocale::Ngiemboon)},
    {sipName_Uighur, static_cast<int>(::QLocale::Uighur)},
    {sipName_Aragonese, static_cast<int>(::QLocale::Aragonese)},
    {sipName_Akkadian, static_cast<int>(::QLocale::Akkadian)},
    {sipName_AncientEgyptian, static_cast<int>(::QLocale::AncientEgyptian)},
    {sipName_AncientGreek, static_cast<int>(::QLocale::AncientGreek)},
    {sipName_Aramaic, static_cast<int>(::QLocale::Aramaic)},
    {sipName_Balinese, static_cast<int>(::QLocale::Balinese)},
    {sipName_Bamun, static_cast<int>(::QLocale::Bamun)},
    {sipName_BatakToba, static_cast<int>(::QLocale::BatakToba)},
    {sipName_Buginese, static_cast<int>(::QLocale::Buginese)},
    {sipName_Chakma, static_cast<int>(::QLocale::Chakma)},
    {sipName_Coptic, static_cast<int>(::QLocale::Coptic)},
    {sipName_Dogri, static_cast<int>(::QLocale::Dogri)},
    {sipName_Gothic, static_cast<int>(::QLocale::Gothic)},
    {sipName_Ingush, static_cast<int>(::QLocale::Ingush)},
    {sipName_Mandingo, static_cast<int>(::QLocale::Mandingo)},
    {sipName_Manipuri, static_cast<int>(::QLocale::Manipuri)},
    {sipName_OldIrish, static_cast<int>(::QLocale::OldIrish)},
    {sipName_OldNorse, static_cast<int>(::QLocale::OldNorse)},
    {sipName_OldPersian, static_cast<int>(::QLocale::OldPersian)},
    {sipName_Pahlavi, static_cast<int>(::QLocale::Pahlavi)},
    {sipName_Phoenician, static_cast<int>(::QLocale::Phoenician)},
    {sipName_Santali, static_cast<int>(::QLocale::Santali)},
    {sipName_Saurashtra, static_cast<int>(::QLocale::Saurashtra)},
    {sipName_TaiDam, static_cast<int>(::QLocale::TaiDam)},
    {sipName_Ugaritic, static_cast<int>(::QLocale::Ugaritic)},
    {sipName_Akoose, static_cast<int>(::QLocale::Akoose)},
    {sipName_Lakota, static_cast<int>(::QLocale::Lakota)},
    {sipName_StandardMoroccanTamazight, static_cast<int>(::QLocale::StandardMoroccanTamazight)},
    {sipName_Mapuche, static_cast<int>(::QLocale::Mapuche)},
    {sipName_CentralKurdish, static_cast<int>(::QLocale::CentralKurdish)},
    {sipName_LowerSorbian, static_cast<int>(::QLocale::LowerSorbian)},
    {sipName_UpperSorbian, static_cast<int>(::QLocale::UpperSorbian)},
    {sipName_Kenyang, static_cast<int>(::QLocale::Kenyang)},
    {sipName_Mohawk, static_cast<int>(::QLocale::Mohawk)},
    {sipName_Nko, static_cast<int>(::QLocale::Nko)},
    {sipName_Prussian, static_cast<int>(::QLocale::Prussian)},
    {sipName_Kiche, static_cast<int>(::QLocale::Kiche)},
    {sipName_SouthernSami, static_cast<int>(::QLocale::SouthernSami)},
    {sipName_LuleSami, static_cast<int>(::QLocale::LuleSami)},
    {sipName_InariSami, static_cast<int>(::QLocale::InariSami)},
    {sipName_SkoltSami, static_cast<int>(::QLocale::SkoltSami)},
    {sipName_Warlpiri, static_cast<int>(::QLocale::Warlpiri)},
    {sipName_Mende, static_cast<int>(::QLocale::Mende)},
    {sipName_Lezghian, static_cast<int>(::QLocale::Lezghian)},
    {sipName_Maithili, static_cast<int>(::QLocale::Maithili)},
    {sipName_AmericanSignLanguage, static_cast<int>(::QLocale::AmericanSignLanguage)},
    {sipName_Bhojpuri, static_cast<int>(::QLocale::Bhojpuri)},
    {sipName_LiteraryChinese, static_cast<int>(::QLocale::LiteraryChinese)},
    {sipName_Mazanderani, static_cast<int>(::QLocale::Mazanderani)},
    {sipName_Newari, static_cast<int>(::QLocale::Newari)},
    {sipName_NorthernLuri, static_cast<int>(::QLocale::NorthernLuri)},
    {sipName_Palauan, static_cast<int>(::QLocale::Palauan)},
    {sipName_Papiamento, static_cast<int>(::QLocale::Papiamento)},
    {sipName_TokelauLanguage, static_cast<int>(::QLocale::TokelauLanguage)},
    {sipName_TokPisin, static_cast<int>(::QLocale::TokPisin)},
    {sipName_TuvaluLanguage, static_cast<int>(::QLocale::TuvaluLanguage)},
    {sipName_Cantonese, static_cast<int>(::QLocale::Cantonese)},
    {sipName_Osage, static_cast<int>(::QLocale::Osage)},
    {sipName_Ido, static_cast<int>(::QLocale::Ido)},
    {sipName_Lojban, static_cast<int>(::QLocale::Lojban)},
    {sipName_Sicilian, static_cast<int>(::QLocale::Sicilian)},
    {sipName_SouthernKurdish, static_cast<int>(::QLocale::SouthernKurdish)},
    {sipName_WesternBalochi, static_cast<int>(::QLocale::WesternBalochi)},
    {sipName_Cebuano, static_cast<int>(::QLocale::Cebuano)},
    {sipName_Erzya, static_cast<int>(::QLocale::Erzya)},
    {sipName_Chickasaw, static_cast<int>(::QLocale::Chickasaw)},
    {sipName_Muscogee, static_cast<int>(::QLocale::Muscogee)},
    {sipName_Silesian, static_cast<int>(::QLocale::Silesian)},
    {sipName_NigerianPidgin, static_cast<int>(::QLocale::NigerianPidgin)},
    {sipName_Bangla, static_cast<int>(::QLocale::Bangla)},
    {sipName_CentralAtlasTamazight, static_cast<int>(::QLocale::CentralAtlasTamazight)},
    {sipName_Inupiaq, static_cast<int>(::QLocale::Inupiaq)},
    {sipName_Kalaallisut, static_cast<int>(::QLocale::Kalaallisut)},
    {sipName_Kuanyama, static_cast<int>(::QLocale::Kuanyama)},
    {sipName_Kyrgyz, static_cast<int>(::QLocale::Kyrgyz)},
    {sipName_Navajo, static_cast<int>(::QLocale::Navajo)},
    {sipName_Odia, static_cast<int>(::QLocale::Odia)},
    {sipName_Uyghur, static_cast<int>(::QLocale::Uyghur)},
    {sipName_Wolaytta, static_cast<int>(::QLocale::Wolaytta)},
    {sipName_Kaingang, static_cast<int>(::QLocale::Kaingang)},
    {sipName_Nheengatu, static_cast<int>(::QLocale::Nheengatu)},
    {sipName_Haryanvi, static_cast<int>(::QLocale::Haryanvi)},
    {sipName_NorthernFrisian, static_cast<int>(::QLocale::NorthernFrisian)},
    {sipName_Rajasthani, static_cast<int>(::QLocale::Rajasthani)},
    {sipName_Moksha, static_cast<int>(::QLocale::Moksha)},
    {sipName_TokiPona, static_cast<int>(::QLocale::TokiPona)},
    {sipName_Pijin, static_cast<int>(::QLocale::Pijin)},
    {sipName_Obolo, static_cast<int>(::QLocale::Obolo)},
    {sipName_Baluchi, static_cast<int>(::QLocale::Baluchi)},
    {sipName_Ligurian, static_cast<int>(::QLocale::Ligurian)},
    {sipName_Rohingya, static_cast<int>(::QLocale::Rohingya)},
    {sipName_Torwali, static_cast<int>(::QLocale::Torwali)},
    {sipName_Anii, static_cast<int>(::QLocale::Anii)},
    {sipName_Kangri, static_cast<int>(::QLocale::Kangri)},
    {sipName_Venetian, static_cast<int>(::QLocale::Venetian)},
    {sipName_Kuvi, static_cast<int>(::QLocale::Kuvi)},
    {sipName_KaraKalpak, static_cast<int>(::QLocale::KaraKalpak)},
    {sipName_SwampyCree, static_cast<int>(::QLocale::SwampyCree)},
    {sipName_Ladin, static_cast<int>(::QLocale::Ladin)},
    {sipName_Shan, static_cast<int>(::QLocale::Shan)},
    {sipName_ISO639Part1, static_cast<int>(::QLocale::ISO639Part1)},
    {sipName_ISO639Part2B, static_cast<int>(::QLocale::ISO639Part2B)},
    {sipName_ISO639Part2T, static_cast<int>(::QLocale::ISO639Part2T)},
    {sipName_ISO639Part3, static_cast<int>(::QLocale::ISO639Part3)},
    {sipName_LegacyLanguageCode, static_cast<int>(::QLocale::LegacyLanguageCode)},
    {sipName_ISO639Part2, static_cast<int>(::QLocale::ISO639Part2)},
    {sipName_ISO639Alpha2, static_cast<int>(::QLocale::ISO639Alpha2)},
    {sipName_ISO639Alpha3, static_cast<int>(::QLocale::ISO639Alpha3)},
    {sipName_ISO639, static_cast<int>(::QLocale::ISO639)},
    {sipName_AnyLanguageCode, static_cast<int>(::QLocale::AnyLanguageCode)},
    {sipName_MetricSystem, static_cast<int>(::QLocale::MetricSystem)},
    {sipName_ImperialSystem, static_cast<int>(::QLocale::ImperialSystem)},
    {sipName_ImperialUSSystem, static_cast<int>(::QLocale::ImperialUSSystem)},
    {sipName_ImperialUKSystem, static_cast<int>(::QLocale::ImperialUKSystem)},
    {sipName_OmitGroupSeparator, static_cast<int>(::QLocale::OmitGroupSeparator)},
    {sipName_RejectGroupSeparator, static_cast<int>(::QLocale::RejectGroupSeparator)},
    {sipName_DefaultNumberOptions, static_cast<int>(::QLocale::DefaultNumberOptions)},
    {sipName_OmitLeadingZeroInExponent, static_cast<int>(::QLocale::OmitLeadingZeroInExponent)},
    {sipName_RejectLeadingZeroInExponent, static_cast<int>(::QLocale::RejectLeadingZeroInExponent)},
    {sipName_IncludeTrailingZeroesAfterDot, static_cast<int>(::QLocale::IncludeTrailingZeroesAfterDot)},
    {sipName_RejectTrailingZeroesAfterDot, static_cast<int>(::QLocale::RejectTrailingZeroesAfterDot)},
    {sipName_StandardQuotation, static_cast<int>(::QLocale::StandardQuotation)},
    {sipName_AlternateQuotation, static_cast<int>(::QLocale::AlternateQuotation)},
    {sipName_AnyScript, static_cast<int>(::QLocale::AnyScript)},
    {sipName_ArabicScript, static_cast<int>(::QLocale::ArabicScript)},
    {sipName_CyrillicScript, static_cast<int>(::QLocale::CyrillicScript)},
    {sipName_DeseretScript, static_cast<int>(::QLocale::DeseretScript)},
    {sipName_GurmukhiScript, static_cast<int>(::QLocale::GurmukhiScript)},
    {sipName_SimplifiedHanScript, static_cast<int>(::QLocale::SimplifiedHanScript)},
    {sipName_TraditionalHanScript, static_cast<int>(::QLocale::TraditionalHanScript)},
    {sipName_LatinScript, static_cast<int>(::QLocale::LatinScript)},
    {sipName_MongolianScript, static_cast<int>(::QLocale::MongolianScript)},
    {sipName_TifinaghScript, static_cast<int>(::QLocale::TifinaghScript)},
    {sipName_SimplifiedChineseScript, static_cast<int>(::QLocale::SimplifiedChineseScript)},
    {sipName_TraditionalChineseScript, static_cast<int>(::QLocale::TraditionalChineseScript)},
    {sipName_ArmenianScript, static_cast<int>(::QLocale::ArmenianScript)},
    {sipName_BengaliScript, static_cast<int>(::QLocale::BengaliScript)},
    {sipName_CherokeeScript, static_cast<int>(::QLocale::CherokeeScript)},
    {sipName_DevanagariScript, static_cast<int>(::QLocale::DevanagariScript)},
    {sipName_EthiopicScript, static_cast<int>(::QLocale::EthiopicScript)},
    {sipName_GeorgianScript, static_cast<int>(::QLocale::GeorgianScript)},
    {sipName_GreekScript, static_cast<int>(::QLocale::GreekScript)},
    {sipName_GujaratiScript, static_cast<int>(::QLocale::GujaratiScript)},
    {sipName_HebrewScript, static_cast<int>(::QLocale::HebrewScript)},
    {sipName_JapaneseScript, static_cast<int>(::QLocale::JapaneseScript)},
    {sipName_KhmerScript, static_cast<int>(::QLocale::KhmerScript)},
    {sipName_KannadaScript, static_cast<int>(::QLocale::KannadaScript)},
    {sipName_KoreanScript, static_cast<int>(::QLocale::KoreanScript)},
    {sipName_LaoScript, static_cast<int>(::QLocale::LaoScript)},
    {sipName_MalayalamScript, static_cast<int>(::QLocale::MalayalamScript)},
    {sipName_MyanmarScript, static_cast<int>(::QLocale::MyanmarScript)},
    {sipName_OriyaScript, static_cast<int>(::QLocale::OriyaScript)},
    {sipName_TamilScript, static_cast<int>(::QLocale::TamilScript)},
    {sipName_TeluguScript, static_cast<int>(::QLocale::TeluguScript)},
    {sipName_ThaanaScript, static_cast<int>(::QLocale::ThaanaScript)},
    {sipName_ThaiScript, static_cast<int>(::QLocale::ThaiScript)},
    {sipName_TibetanScript, static_cast<int>(::QLocale::TibetanScript)},
    {sipName_SinhalaScript, static_cast<int>(::QLocale::SinhalaScript)},
    {sipName_SyriacScript, static_cast<int>(::QLocale::SyriacScript)},
    {sipName_YiScript, static_cast<int>(::QLocale::YiScript)},
    {sipName_VaiScript, static_cast<int>(::QLocale::VaiScript)},
    {sipName_AvestanScript, static_cast<int>(::QLocale::AvestanScript)},
    {sipName_BalineseScript, static_cast<int>(::QLocale::BalineseScript)},
    {sipName_BamumScript, static_cast<int>(::QLocale::BamumScript)},
    {sipName_BatakScript, static_cast<int>(::QLocale::BatakScript)},
    {sipName_BopomofoScript, static_cast<int>(::QLocale::BopomofoScript)},
    {sipName_BrahmiScript, static_cast<int>(::QLocale::BrahmiScript)},
    {sipName_BugineseScript, static_cast<int>(::QLocale::BugineseScript)},
    {sipName_BuhidScript, static_cast<int>(::QLocale::BuhidScript)},
    {sipName_CanadianAboriginalScript, static_cast<int>(::QLocale::CanadianAboriginalScript)},
    {sipName_CarianScript, static_cast<int>(::QLocale::CarianScript)},
    {sipName_ChakmaScript, static_cast<int>(::QLocale::ChakmaScript)},
    {sipName_ChamScript, static_cast<int>(::QLocale::ChamScript)},
    {sipName_CopticScript, static_cast<int>(::QLocale::CopticScript)},
    {sipName_CypriotScript, static_cast<int>(::QLocale::CypriotScript)},
    {sipName_EgyptianHieroglyphsScript, static_cast<int>(::QLocale::EgyptianHieroglyphsScript)},
    {sipName_FraserScript, static_cast<int>(::QLocale::FraserScript)},
    {sipName_GlagoliticScript, static_cast<int>(::QLocale::GlagoliticScript)},
    {sipName_GothicScript, static_cast<int>(::QLocale::GothicScript)},
    {sipName_HanScript, static_cast<int>(::QLocale::HanScript)},
    {sipName_HangulScript, static_cast<int>(::QLocale::HangulScript)},
    {sipName_HanunooScript, static_cast<int>(::QLocale::HanunooScript)},
    {sipName_ImperialAramaicScript, static_cast<int>(::QLocale::ImperialAramaicScript)},
    {sipName_InscriptionalPahlaviScript, static_cast<int>(::QLocale::InscriptionalPahlaviScript)},
    {sipName_InscriptionalParthianScript, static_cast<int>(::QLocale::InscriptionalParthianScript)},
    {sipName_JavaneseScript, static_cast<int>(::QLocale::JavaneseScript)},
    {sipName_KaithiScript, static_cast<int>(::QLocale::KaithiScript)},
    {sipName_KatakanaScript, static_cast<int>(::QLocale::KatakanaScript)},
    {sipName_KayahLiScript, static_cast<int>(::QLocale::KayahLiScript)},
    {sipName_KharoshthiScript, static_cast<int>(::QLocale::KharoshthiScript)},
    {sipName_LannaScript, static_cast<int>(::QLocale::LannaScript)},
    {sipName_LepchaScript, static_cast<int>(::QLocale::LepchaScript)},
    {sipName_LimbuScript, static_cast<int>(::QLocale::LimbuScript)},
    {sipName_LinearBScript, static_cast<int>(::QLocale::LinearBScript)},
    {sipName_LycianScript, static_cast<int>(::QLocale::LycianScript)},
    {sipName_LydianScript, static_cast<int>(::QLocale::LydianScript)},
    {sipName_MandaeanScript, static_cast<int>(::QLocale::MandaeanScript)},
    {sipName_MeiteiMayekScript, static_cast<int>(::QLocale::MeiteiMayekScript)},
    {sipName_MeroiticScript, static_cast<int>(::QLocale::MeroiticScript)},
    {sipName_MeroiticCursiveScript, static_cast<int>(::QLocale::MeroiticCursiveScript)},
    {sipName_NkoScript, static_cast<int>(::QLocale::NkoScript)},
    {sipName_NewTaiLueScript, static_cast<int>(::QLocale::NewTaiLueScript)},
    {sipName_OghamScript, static_cast<int>(::QLocale::OghamScript)},
    {sipName_OlChikiScript, static_cast<int>(::QLocale::OlChikiScript)},
    {sipName_OldItalicScript, static_cast<int>(::QLocale::OldItalicScript)},
    {sipName_OldPersianScript, static_cast<int>(::QLocale::OldPersianScript)},
    {sipName_OldSouthArabianScript, static_cast<int>(::QLocale::OldSouthArabianScript)},
    {sipName_OrkhonScript, static_cast<int>(::QLocale::OrkhonScript)},
    {sipName_OsmanyaScript, static_cast<int>(::QLocale::OsmanyaScript)},
    {sipName_PhagsPaScript, static_cast<int>(::QLocale::PhagsPaScript)},
    {sipName_PhoenicianScript, static_cast<int>(::QLocale::PhoenicianScript)},
    {sipName_PollardPhoneticScript, static_cast<int>(::QLocale::PollardPhoneticScript)},
    {sipName_RejangScript, static_cast<int>(::QLocale::RejangScript)},
    {sipName_RunicScript, static_cast<int>(::QLocale::RunicScript)},
    {sipName_SamaritanScript, static_cast<int>(::QLocale::SamaritanScript)},
    {sipName_SaurashtraScript, static_cast<int>(::QLocale::SaurashtraScript)},
    {sipName_SharadaScript, static_cast<int>(::QLocale::SharadaScript)},
    {sipName_ShavianScript, static_cast<int>(::QLocale::ShavianScript)},
    {sipName_SoraSompengScript, static_cast<int>(::QLocale::SoraSompengScript)},
    {sipName_CuneiformScript, static_cast<int>(::QLocale::CuneiformScript)},
    {sipName_SundaneseScript, static_cast<int>(::QLocale::SundaneseScript)},
    {sipName_SylotiNagriScript, static_cast<int>(::QLocale::SylotiNagriScript)},
    {sipName_TagalogScript, static_cast<int>(::QLocale::TagalogScript)},
    {sipName_TagbanwaScript, static_cast<int>(::QLocale::TagbanwaScript)},
    {sipName_TaiLeScript, static_cast<int>(::QLocale::TaiLeScript)},
    {sipName_TaiVietScript, static_cast<int>(::QLocale::TaiVietScript)},
    {sipName_TakriScript, static_cast<int>(::QLocale::TakriScript)},
    {sipName_UgariticScript, static_cast<int>(::QLocale::UgariticScript)},
    {sipName_BrailleScript, static_cast<int>(::QLocale::BrailleScript)},
    {sipName_HiraganaScript, static_cast<int>(::QLocale::HiraganaScript)},
    {sipName_CaucasianAlbanianScript, static_cast<int>(::QLocale::CaucasianAlbanianScript)},
    {sipName_BassaVahScript, static_cast<int>(::QLocale::BassaVahScript)},
    {sipName_DuployanScript, static_cast<int>(::QLocale::DuployanScript)},
    {sipName_ElbasanScript, static_cast<int>(::QLocale::ElbasanScript)},
    {sipName_GranthaScript, static_cast<int>(::QLocale::GranthaScript)},
    {sipName_PahawhHmongScript, static_cast<int>(::QLocale::PahawhHmongScript)},
    {sipName_KhojkiScript, static_cast<int>(::QLocale::KhojkiScript)},
    {sipName_LinearAScript, static_cast<int>(::QLocale::LinearAScript)},
    {sipName_MahajaniScript, static_cast<int>(::QLocale::MahajaniScript)},
    {sipName_ManichaeanScript, static_cast<int>(::QLocale::ManichaeanScript)},
    {sipName_MendeKikakuiScript, static_cast<int>(::QLocale::MendeKikakuiScript)},
    {sipName_ModiScript, static_cast<int>(::QLocale::ModiScript)},
    {sipName_MroScript, static_cast<int>(::QLocale::MroScript)},
    {sipName_OldNorthArabianScript, static_cast<int>(::QLocale::OldNorthArabianScript)},
    {sipName_NabataeanScript, static_cast<int>(::QLocale::NabataeanScript)},
    {sipName_PalmyreneScript, static_cast<int>(::QLocale::PalmyreneScript)},
    {sipName_PauCinHauScript, static_cast<int>(::QLocale::PauCinHauScript)},
    {sipName_OldPermicScript, static_cast<int>(::QLocale::OldPermicScript)},
    {sipName_PsalterPahlaviScript, static_cast<int>(::QLocale::PsalterPahlaviScript)},
    {sipName_SiddhamScript, static_cast<int>(::QLocale::SiddhamScript)},
    {sipName_KhudawadiScript, static_cast<int>(::QLocale::KhudawadiScript)},
    {sipName_TirhutaScript, static_cast<int>(::QLocale::TirhutaScript)},
    {sipName_VarangKshitiScript, static_cast<int>(::QLocale::VarangKshitiScript)},
    {sipName_AhomScript, static_cast<int>(::QLocale::AhomScript)},
    {sipName_AnatolianHieroglyphsScript, static_cast<int>(::QLocale::AnatolianHieroglyphsScript)},
    {sipName_HatranScript, static_cast<int>(::QLocale::HatranScript)},
    {sipName_MultaniScript, static_cast<int>(::QLocale::MultaniScript)},
    {sipName_OldHungarianScript, static_cast<int>(::QLocale::OldHungarianScript)},
    {sipName_SignWritingScript, static_cast<int>(::QLocale::SignWritingScript)},
    {sipName_AdlamScript, static_cast<int>(::QLocale::AdlamScript)},
    {sipName_BhaiksukiScript, static_cast<int>(::QLocale::BhaiksukiScript)},
    {sipName_MarchenScript, static_cast<int>(::QLocale::MarchenScript)},
    {sipName_NewaScript, static_cast<int>(::QLocale::NewaScript)},
    {sipName_OsageScript, static_cast<int>(::QLocale::OsageScript)},
    {sipName_TangutScript, static_cast<int>(::QLocale::TangutScript)},
    {sipName_HanWithBopomofoScript, static_cast<int>(::QLocale::HanWithBopomofoScript)},
    {sipName_JamoScript, static_cast<int>(::QLocale::JamoScript)},
    {sipName_BanglaScript, static_cast<int>(::QLocale::BanglaScript)},
    {sipName_MendeScript, static_cast<int>(::QLocale::MendeScript)},
    {sipName_OdiaScript, static_cast<int>(::QLocale::OdiaScript)},
    {sipName_HanifiScript, static_cast<int>(::QLocale::HanifiScript)},
    {sipName_Dash, static_cast<int>(::QLocale::TagSeparator::Dash)},
    {sipName_Underscore, static_cast<int>(::QLocale::TagSeparator::Underscore)},
    {0, 0}
};

PyDoc_STRVAR(doc_QLocale, "\1QLocale()\n"
"QLocale(name: str|None)\n"
"QLocale(language: QLocale.Language, country: QLocale.Country = QLocale.AnyCountry)\n"
"QLocale(language: QLocale.Language, script: QLocale.Script, country: QLocale.Country)\n"
"QLocale(other: QLocale)");


sipClassTypeDef sipTypeDef_QtCore_QLocale = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLocale,
        SIP_NULLPTR,
        SIP_NULLPTR,
    },
    {
        sipNameNr_QLocale,
        {0, 0, 1},
        71, methods_QLocale,
        1, variables_QLocale,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QLocale, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLocale,
    -1,
    sipNameNr_PyQt6_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLocale,
    init_type_QLocale,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLocale,
    assign_QLocale,
    array_QLocale,
    copy_QLocale,
    release_QLocale,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLocale,
    sizeof (::QLocale),
};
